@@ -1,7 +1,7 @@
 /*
  * @(#)Barrel.c
  *
- * Copyright 2003 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 2003 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -98,7 +98,7 @@ static void randomizePuzzleWithQuery(BarrelWidget w,
 	XEvent *event, char **args, int nArgs);
 static void randomizePuzzleWithDoubleClick(BarrelWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(BarrelWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(BarrelWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(BarrelWidget w,
 	XEvent *event, char **args, int nArgs);
 static void undoPuzzle(BarrelWidget w, XEvent *event, char **args, int nArgs);
@@ -174,10 +174,10 @@ static char translations[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -202,7 +202,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1301,17 +1301,17 @@ controlPuzzle(BarrelWidget w, int direction)
 
 	switch (direction) {
 	case TOP:
-		if (w->barrel.faces <= MIN_FACES)
+		if (w->barrel.faces >= MAX_FACES)
 			return;
-		reason = ACTION_DECY;
+		reason = ACTION_INCY;
 		break;
 	case RIGHT:
 		reason = ACTION_INCX;
 		break;
 	case BOTTOM:
-		if (w->barrel.faces >= MAX_FACES)
+		if (w->barrel.faces <= MIN_FACES)
 			return;
-		reason = ACTION_INCY;
+		reason = ACTION_DECY;
 		break;
 	case LEFT:
 		if (w->barrel.tiles <= MIN_TILES)
@@ -1587,7 +1587,7 @@ resetTiles(BarrelWidget w)
 }
 
 static void
-getTiles(BarrelWidget w)
+readTiles(BarrelWidget w)
 {
 	FILE *fp;
 	int c, i, tiles, faces, pairs, orient, practice, moves;
@@ -1605,7 +1605,7 @@ getTiles(BarrelWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1619,7 +1619,7 @@ getTiles(BarrelWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2311,8 +2311,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->barrel.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getTiles(w);
+		case ACTION_READ:
+			readTiles(w);
 			break;
 		case ACTION_WRITE:
 			writeTiles(w);
@@ -2895,13 +2895,13 @@ randomizePuzzleWithDoubleClick(BarrelWidget w
 static
 #endif
 void
-getPuzzle(BarrelWidget w
+readPuzzle(BarrelWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getTiles(w);
+	readTiles(w);
 }
 
 #ifndef WINVER
