@@ -1,7 +1,7 @@
 /*
  * @(#)BarrelP.h
  *
- * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 2003 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -42,7 +42,7 @@ extern void releasePuzzle(BarrelWidget w,
 	const int x, const int y, const int shift);
 extern void practicePuzzle(BarrelWidget w);
 extern void randomizePuzzle(BarrelWidget w);
-extern void getPuzzle(BarrelWidget w);
+extern void readPuzzle(BarrelWidget w);
 extern void writePuzzle(BarrelWidget w);
 extern void undoPuzzle(BarrelWidget w);
 extern void redoPuzzle(BarrelWidget w);
