@@ -1,29 +1,24 @@
-/*-
-# X-BASED BARREL(tm)
-#
-#  BarrelU.c
-#
-###
-#
-#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)BarrelU.c
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
-/* Undo algorithm */
+/* Undo algorithm for Barrel */
 
 #include "BarrelP.h"
 
@@ -48,7 +43,7 @@ newStack(BarrelStack *s)
 }
 
 static void
-pushStack(BarrelStack *s, MoveRecord **move)
+pushStack(BarrelStack *s, moveRecord **move)
 {
 	if (!(s->currMove = (MoveStack *) malloc(sizeof (MoveStack)))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
@@ -71,7 +66,7 @@ popStack(BarrelStack *s)
 	s->count--;
 }
 
-static MoveRecord *
+static moveRecord *
 topStack(BarrelStack *s)
 {
 	return &(s->lastMove->previous->move);
@@ -124,7 +119,7 @@ deleteMoves(BarrelStack *s)
 }
 
 static void
-writeMove(MoveRecord *move, int direction, int tile, int control)
+writeMove(moveRecord *move, int direction, int tile, int control)
 {
 #if 0
 	move->direction = direction;
@@ -135,7 +130,7 @@ writeMove(MoveRecord *move, int direction, int tile, int control)
 }
 
 static void
-readMove(MoveRecord *move, int *direction, int *tile, int *control)
+readMove(moveRecord *move, int *direction, int *tile, int *control)
 {
 #if 0
 	*direction = move->direction;
@@ -149,7 +144,7 @@ readMove(MoveRecord *move, int *direction, int *tile, int *control)
 void
 setMove(BarrelStack *s, int direction, int tile, int control)
 {
-	MoveRecord *move;
+	moveRecord *move;
 
 	pushStack(s, &move);
 	writeMove(move, direction, tile, control);
@@ -197,7 +192,7 @@ scanMoves(FILE *fp, BarrelWidget w, int moves)
 	for (l = 0; l < moves; l++) {
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d", &direction, &tile, &shift);
-		if (!MovePuzzle(w, direction, tile, shift, False, INSTANT))
+		if (!movePuzzle(w, direction, tile, shift, False, INSTANT))
 			(void) fprintf(stderr,
 				"%d move in direction %d, tile %d, shift %d, can not be made.",
 				l, direction, tile, shift);
@@ -256,5 +251,5 @@ setStartPosition(BarrelWidget w)
 			w->barrel.spacePosition[i] = startSpace[i];
 	for (i = 0; i < w->barrel.tileFaces; i++)
 		w->barrel.tileOfPosition[i] = startPosition[i];
-	DrawAllTiles(w);
+	drawAllTiles(w);
 }
