@@ -1,7 +1,7 @@
 /*
  * @(#)Cubes.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -80,7 +80,7 @@ static void clearWithQueryPuzzle(CubesWidget w,
 	XEvent *event, char **args, int nArgs);
 static void clearWithDoubleClickPuzzle(CubesWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(CubesWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(CubesWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(CubesWidget w, XEvent *event, char **args, int nArgs);
 static void undoPuzzle(CubesWidget w, XEvent *event, char **args, int nArgs);
 static void redoPuzzle(CubesWidget w, XEvent *event, char **args, int nArgs);
@@ -154,10 +154,10 @@ static char translations[] =
  <Btn3Down>(2+): Clear2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -178,7 +178,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Release", (XtActionProc) releasePuzzle},
 	{(char *) "ClearMaybe", (XtActionProc) clearWithQueryPuzzle},
 	{(char *) "Clear2", (XtActionProc) clearWithDoubleClickPuzzle},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -244,13 +244,13 @@ static XtResource resources[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNsizeX, XtCSizeX, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeX),
-	 XtRString, (caddr_t) "4"}, /* DEFAULT_CUBESX */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_BLOCKSX */
 	{XtNsizeY, XtCSizeY, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeY),
-	 XtRString, (caddr_t) "4"}, /* DEFAULT_CUBESY */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_BLOCKSY */
 	{XtNsizeZ, XtCSizeZ, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeZ),
-	 XtRString, (caddr_t) "1"}, /* DEFAULT_CUBESZ */
+	 XtRString, (caddr_t) "1"}, /* DEFAULT_BLOCKSZ */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.base),
 	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
@@ -387,41 +387,41 @@ checkBlocks(CubesWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->cubes.sizeX < MIN_CUBES) {
+	if (w->cubes.sizeX < MIN_BLOCKS) {
 		intCat(&buf1,
 			"Number of cubes in X direction out of bounds, use at least ",
-			MIN_CUBES);
+			MIN_BLOCKS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULT_CUBESX);
+		intCat(&buf1, buf2, DEFAULT_BLOCKSX);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeX = DEFAULT_CUBESX;
+		w->cubes.sizeX = DEFAULT_BLOCKSX;
 	}
-	if (w->cubes.sizeY < MIN_CUBES) {
+	if (w->cubes.sizeY < MIN_BLOCKS) {
 		intCat(&buf1,
 			"Number of cubes in Y direction out of bounds, use at least ",
-			MIN_CUBES);
+			MIN_BLOCKS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULT_CUBESY);
+		intCat(&buf1, buf2, DEFAULT_BLOCKSY);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeY = DEFAULT_CUBESY;
+		w->cubes.sizeY = DEFAULT_BLOCKSY;
 	}
-	if (w->cubes.sizeZ < MIN_CUBES) {
+	if (w->cubes.sizeZ < MIN_BLOCKS) {
 		intCat(&buf1,
 			"Number of cubes in Z direction out of bounds, use at least ",
-			MIN_CUBES);
+			MIN_BLOCKS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULT_CUBESZ);
+		intCat(&buf1, buf2, DEFAULT_BLOCKSZ);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeZ = DEFAULT_CUBESZ;
+		w->cubes.sizeZ = DEFAULT_BLOCKSZ;
 	}
 	if (w->cubes.delay < 0) {
 		intCat(&buf1, "Delay can not be negative (",
@@ -1269,23 +1269,23 @@ movePuzzle(CubesWidget w, const int direction, const int control)
 		reason = ACTION_IGNORE;
 		switch (direction) {
 		case TOP:
-			if (w->cubes.sizeY <= MIN_CUBES)
-				return FALSE;
-			reason = ACTION_DECY;
+			reason = ACTION_INCY;
 			break;
 		case RIGHT:
 			reason = ACTION_INCX;
 			break;
 		case BOTTOM:
-			reason = ACTION_INCY;
+			if (w->cubes.sizeY <= MIN_BLOCKS)
+				return FALSE;
+			reason = ACTION_DECY;
 			break;
 		case LEFT:
-			if (w->cubes.sizeX <= MIN_CUBES)
+			if (w->cubes.sizeX <= MIN_BLOCKS)
 				return FALSE;
 			reason = ACTION_DECX;
 			break;
 		case INWARDS:
-			if (w->cubes.sizeZ <= MIN_CUBES)
+			if (w->cubes.sizeZ <= MIN_BLOCKS)
 				return FALSE;
 			reason = ACTION_DECZ;
 			break;
@@ -1590,7 +1590,7 @@ resetBlocks(CubesWidget w)
 }
 
 static void
-getBlocks(CubesWidget w)
+readBlocks(CubesWidget w)
 {
 	FILE *fp;
 	int c, i, sizeX, sizeY, sizeZ, moves;
@@ -1608,7 +1608,7 @@ getBlocks(CubesWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get)", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1622,7 +1622,7 @@ getBlocks(CubesWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get)", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1636,7 +1636,7 @@ getBlocks(CubesWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeX);
-	if (sizeX >= MIN_CUBES) {
+	if (sizeX >= MIN_BLOCKS) {
 		for (i = w->cubes.sizeX; i < sizeX; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -1649,7 +1649,7 @@ getBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MIN_CUBES);
+		intCat(&buf2, buf1, MIN_BLOCKS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1658,7 +1658,7 @@ getBlocks(CubesWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeY);
-	if (sizeY >= MIN_CUBES) {
+	if (sizeY >= MIN_BLOCKS) {
 		for (i = w->cubes.sizeY; i < sizeY; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -1671,7 +1671,7 @@ getBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MIN_CUBES);
+		intCat(&buf2, buf1, MIN_BLOCKS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1680,7 +1680,7 @@ getBlocks(CubesWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeZ);
-	if (sizeZ >= MIN_CUBES) {
+	if (sizeZ >= MIN_BLOCKS) {
 		for (i = w->cubes.sizeZ; i < sizeZ; i++) {
 			setPuzzle(w, ACTION_INCZ);
 		}
@@ -1693,7 +1693,7 @@ getBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MIN_CUBES);
+		intCat(&buf2, buf1, MIN_BLOCKS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1996,11 +1996,11 @@ setValuesPuzzle(CubesWidget w)
 	char szBuf[80];
 
 	w->cubes.sizeX = GetPrivateProfileInt(SECTION,
-		"sizeX", DEFAULT_CUBESX, INIFILE);
+		"sizeX", DEFAULT_BLOCKSX, INIFILE);
 	w->cubes.sizeY = GetPrivateProfileInt(SECTION,
-		"sizeY", DEFAULT_CUBESY, INIFILE);
+		"sizeY", DEFAULT_BLOCKSY, INIFILE);
 	w->cubes.sizeZ = GetPrivateProfileInt(SECTION,
-		"sizeZ", DEFAULT_CUBESZ, INIFILE);
+		"sizeZ", DEFAULT_BLOCKSZ, INIFILE);
 	w->cubes.base = GetPrivateProfileInt(SECTION,
 		"base", DEFAULT_BASE, INIFILE);
 	w->cubes.mono = (BOOL) GetPrivateProfileInt(SECTION,
@@ -2276,8 +2276,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->cubes.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getBlocks(w);
+		case ACTION_READ:
+			readBlocks(w);
 			break;
 		case ACTION_WRITE:
 			writeBlocks(w);
@@ -2705,13 +2705,13 @@ clearWithDoubleClickPuzzle(CubesWidget w
 static
 #endif
 void
-getPuzzle(CubesWidget w
+readPuzzle(CubesWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getBlocks(w);
+	readBlocks(w);
 }
 
 #ifndef WINVER
