@@ -1,7 +1,7 @@
 /*
  * @(#)Cubes.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -79,7 +79,7 @@ typedef struct {
 } cubesCallbackStruct;
 #endif
 
-#define ACTION_GET 100
+#define ACTION_READ 100
 #define ACTION_WRITE 101
 #define ACTION_EXIT 102
 #define ACTION_HIDE 103
@@ -100,16 +100,16 @@ typedef struct {
 #define ACTION_SPEED 205
 #define ACTION_SLOW 206
 #define ACTION_SOUND 207
-#define ACTION_LEFT 303
 #define ACTION_RIGHT 301
+#define ACTION_LEFT 303
 #define ACTION_UP 300
 #define ACTION_DOWN 302
-#define ACTION_IN 304
 #define ACTION_OUT 305
+#define ACTION_IN 304
 #define ACTION_INCX 401
 #define ACTION_DECX 403
-#define ACTION_INCY 402
-#define ACTION_DECY 400
+#define ACTION_INCY 400
+#define ACTION_DECY 402
 #define ACTION_INCZ 405
 #define ACTION_DECZ 404
 #define ACTION_DESCRIPTION 900
@@ -118,10 +118,10 @@ typedef struct {
 #define ACTION_ABOUT 903
 #define ACTION_IGNORE 999
 
-#define MIN_CUBES 1
-#define DEFAULT_CUBESX 4
-#define DEFAULT_CUBESY 4
-#define DEFAULT_CUBESZ 1
+#define MIN_BLOCKS 1
+#define DEFAULT_BLOCKSX 4
+#define DEFAULT_BLOCKSY 4
+#define DEFAULT_BLOCKSZ 1
 #define DEFAULT_DELAY 10
 #ifdef MONOTEST
 #define DEFAULT_MONO TRUE
