@@ -1,7 +1,7 @@
 /*
  * @(#)CubesP.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -38,7 +38,7 @@ extern void hidePuzzle(CubesWidget w);
 extern void selectPuzzle(CubesWidget w, const int x, const int y);
 extern void releasePuzzle(CubesWidget w);
 extern void randomizePuzzle(CubesWidget w);
-extern void getPuzzle(CubesWidget w);
+extern void readPuzzle(CubesWidget w);
 extern void writePuzzle(CubesWidget w);
 extern void undoPuzzle(CubesWidget w);
 extern void redoPuzzle(CubesWidget w);
