@@ -1,38 +1,31 @@
-/*-
-# X-BASED CUBES
-#
-#  CubesS.c
-#
-###
-#
-#  Taken from the X puzzle by Don Bennett, HP Labs
-#
-#  Copyright (c) 2003 - 2007    David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-#  TODO
-#   o handle < 4x4 and 3d
-#
-*/
-
 /*
- *	$XConsortium: puzzle.c,v 1.14 94/03/28 18:34:10 gildea Exp $
+ * @(#)CubesS.c
+ *
+ * Taken from the X puzzle by Don Bennett, HP Labs
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-/* Puzzle - (C) Copyright 1987, 1988 Don Bennett.
+/*
+ * $XConsortium: puzzle.c,v 1.14 94/03/28 18:34:10 gildea Exp $
+ */
+
+/*
+ * Puzzle - (C) Copyright 1987, 1988 Don Bennett.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -41,19 +34,25 @@
  * supporting documentation.
  */
 
-/**
- **  Puzzle
- **
- ** Don Bennett, HP Labs
- **
- ** this is the code that does the real work to solve the
- ** puzzle.  (Commonly seen as a 4x4 grid of sliding pieces
- ** numbered 1-15 with one empty space.)
- **
- ** The idea for the solution algorithm - solving the puzzle
- ** in layers working from the outside in - comes to me
- ** indirectly from John Nagle.
- **/
+/*
+ *  Puzzle
+ *
+ * Don Bennett, HP Labs
+ *
+ * this is the code that does the real work to solve the
+ * puzzle.  (Commonly seen as a 4x4 grid of sliding pieces
+ * numbered 1-15 with one empty space.)
+ *
+ * The idea for the solution algorithm - solving the puzzle
+ * in layers working from the outside in - comes to me
+ * indirectly from John Nagle.
+ */
+
+/*
+ *  TODO
+ *    o handle < 4x4 and 3d
+ *
+ */
 
 #define JMP
 #ifdef JMP
@@ -64,24 +63,24 @@
 #define QUEUE_SIZE	1000
 #define SOLVE_COORD	4 /* not 6 for 3D yet */
 
-/** PUZZLE_SIZE MUST be a multiple of 2; **/
+/* PUZZLE_SIZE MUST be a multiple of 2; */
 #define PUZZLE_SIZE (MIN((w->cubes.sizeX/2)*2,(w->cubes.sizeY/2)*2))
-#define DIST(loc1,loc2)	(ABS(Column(loc1)-Column(loc2))+\
-  ABS(Row(loc1)-Row(loc2)))
+#define DIST(loc1,loc2)	(ABS(toColumn(loc1)-toColumn(loc2))+\
+  ABS(toRow(loc1)-toRow(loc2)))
 
 static int otherDir[SOLVE_COORD] = { BOTTOM, LEFT, TOP, RIGHT };
 
-/** layer info macros -> (innermost 4 tiles are layer zero,
- **			ordinal goes up as you move out)
- ** layerDepth		- returns number of (rows down),
- **			(cols across) the layer starts;
- ** layerWidth		- number of blocks wide the layer is;
- **/
+/* layer info macros -> (innermost 4 tiles are layer zero,
+ *			ordinal goes up as you move out)
+ * layerDepth		- returns number of (rows down),
+ *			(cols across) the layer starts;
+ * layerWidth		- number of blocks wide the layer is;
+ */
 
 #define layerDepth(l)	(layers-1-(l))
 #define layerWidth(l)	(PUZZLE_SIZE-2*layerDepth(l))
 
-/** macros for finding the corners of each layer **/
+/* macros for finding the corners of each layer */
 
 #define UL(l) (layerDepth(l)*(PUZZLE_SIZE+1)+\
   extraRows*w->cubes.sizeX + extraColumns*(layers-(l)))
@@ -92,13 +91,13 @@ static int otherDir[SOLVE_COORD] = { BOTTOM, LEFT, TOP, RIGHT };
 #define LR(l) ((layerDepth(l)+layerWidth(l)-1)*(PUZZLE_SIZE+1)+\
   extraRows*PUZZLE_SIZE+extraColumns*(w->cubes.sizeY+1+(l)-layers))
 
-/** get the x and y coordinates of a location in the matrix **/
+/* get the x and y coordinates of a location in the matrix */
 
-#define Column(loc)	((loc)%w->cubes.sizeX)
-#define Row(loc)	((loc)/w->cubes.sizeX)
-#define ToPosition(x,y)	(((y)*w->cubes.sizeX)+(x))
-#define spaceX	Column(w->cubes.spacePosition)
-#define spaceY	Row(w->cubes.spacePosition)
+#define toColumn(loc)	((loc)%w->cubes.sizeX)
+#define toRow(loc)	((loc)/w->cubes.sizeX)
+#define toPosition(x,y)	(((y)*w->cubes.sizeX)+(x))
+#define spaceX	toColumn(w->cubes.spacePosition)
+#define spaceY	toRow(w->cubes.spacePosition)
 
 #define nextLeft(loc)	((loc)-1)
 #define nextRight(loc)	((loc)+1)
@@ -114,28 +113,28 @@ static int *targetM;
 static Boolean *locked;
 static int *locList;
 
-static Boolean SolvingFlag = False;
+static Boolean solvingFlag = False;
 #ifdef JMP
-static Boolean AbortSolvingFlag = False;
+static Boolean abortSolvingFlag = False;
 static jmp_buf solve_env;
 
 static void
-AbortSolving(void)
+abortSolving(void)
 {
-	if (SolvingFlag)
-		AbortSolvingFlag = True;
+	if (solvingFlag)
+		abortSolvingFlag = True;
 }
 
 #ifdef WINVER
 static Boolean
-ProcessMessage(UINT msg)
+processMessage(UINT msg)
 {
 	switch (msg) {
 	case WM_KEYDOWN:
 	case WM_CLOSE:
 	case WM_LBUTTONDOWN:
 	case WM_RBUTTONDOWN:
-		AbortSolving();
+		abortSolving();
 		return True;
 	default:
 		return False;
@@ -143,35 +142,35 @@ ProcessMessage(UINT msg)
 }
 #else
 static void
-ProcessButton(void /*XButtonEvent *event*/)
+processButton(void /*XButtonEvent *event*/)
 {
-	AbortSolving();
+	abortSolving();
 }
 
 static void
-ProcessVisibility(XVisibilityEvent *event)
+processVisibility(XVisibilityEvent *event)
 {
 	if (event->state != VisibilityUnobscured)
-		AbortSolving();
+		abortSolving();
 }
 
 static void
-GetNextEvent(CubesWidget w, XEvent *event)
+getNextEvent(CubesWidget w, XEvent *event)
 {
 	if (!XCheckMaskEvent(XtDisplay(w), VisibilityChangeMask, event))
 		(void) XNextEvent(XtDisplay(w), event);
 }
 
 static void
-ProcessEvent(XEvent *event)
+processEvent(XEvent *event)
 {
 	switch(event->type) {
 	case KeyPress:
 	case ButtonPress:
-		ProcessButton(/*&event->xbutton*/);
+		processButton(/*&event->xbutton*/);
 		break;
 	case VisibilityNotify:
-		ProcessVisibility(&event->xvisibility);
+		processVisibility(&event->xvisibility);
 		break;
 	default:
 		break;
@@ -179,13 +178,13 @@ ProcessEvent(XEvent *event)
 }
 
 static void
-ProcessEvents(CubesWidget w)
+processEvents(CubesWidget w)
 {
 	XEvent event;
 
 	while (XPending(XtDisplay(w))) {
-		GetNextEvent(w, &event);
-		ProcessEvent(&event);
+		getNextEvent(w, &event);
+		processEvent(&event);
 	}
 }
 #endif
@@ -210,35 +209,36 @@ findPiece(CubesWidget w, int piece)
 }
 
 static void
-LogMoveSpace(CubesWidget w,
+logMoveSpace(CubesWidget w,
 		int firstX, int firstY, int lastX, int lastY, int dir)
 {
 	int count = ABS(firstX - lastX) + ABS(firstY - lastY);
 
-	AnimateSlide(w, count + 1, dir, NORMAL, True);
+	animateSlide(w, count + 1, dir, NORMAL, True);
 }
 
 static void
-moveSpace(CubesWidget w, int dir, int dist)
+moveSpace(CubesWidget w, int direction, int distance)
 {
 	int i, step, count;
 	int firstX, firstY, lastX, lastY, shiftDir;
 	int tempSpaceX = spaceX, tempSpaceY = spaceY;
+	int dir = direction, dist = distance;
 
 #ifdef JMP
 #ifdef WINVER
 	MSG msg;
 
 	if (PeekMessage(&msg, NULL, 0, 0, 0)) {
-		if (!ProcessMessage(msg.message)) {
+		if (!processMessage(msg.message)) {
 			if (GetMessage(&msg, NULL, 0, 0))
 				DispatchMessage(&msg);
 		}
 	}
 #else
-	ProcessEvents(w);
+	processEvents(w);
 #endif
-	if (SolvingFlag && AbortSolvingFlag)
+	if (solvingFlag && abortSolvingFlag)
 		longjmp(solve_env, 1);
 #endif
 	if (dist == 0)
@@ -261,13 +261,13 @@ moveSpace(CubesWidget w, int dir, int dist)
 		count = -count;
 	}
 
-	/** firstX,Y are the location of the first piece to be shifted **/
+	/* firstX,Y are the location of the first piece to be shifted */
 	if (dir == RIGHT)
 		firstX += step;
 	else
 		firstY += step;
 
-	/** shiftDir is the direction the pieces need to be shifted **/
+	/* shiftDir is the direction the pieces need to be shifted */
 	if (dist < 0) {
 		shiftDir = dir;
 	} else {
@@ -276,18 +276,18 @@ moveSpace(CubesWidget w, int dir, int dist)
 	for (i = 0; i < count; i++) {
 		if (dir == RIGHT) {
 			tempSpaceX += step;
-		} else { /** dir == BOTTOM **/
+		} else { /* dir == BOTTOM */
 			tempSpaceY += step;
 		}
 	}
 	lastX = tempSpaceX;
 	lastY = tempSpaceY;
 
-	/** the blocks firstX,Y through lastX,Y need to be shifted
-	 ** one block in the shiftDir direction;
-	 **/
+	/* the blocks firstX,Y through lastX,Y need to be shifted
+	 * one block in the shiftDir direction;
+	 */
 
-	LogMoveSpace(w, firstX, firstY, lastX, lastY, shiftDir);
+	logMoveSpace(w, firstX, firstY, lastX, lastY, shiftDir);
 }
 
 #ifdef DEBUG
@@ -298,7 +298,7 @@ printMatrix(CubesWidget w, int **mat)
 
 	for (j = 0; j < w->cubes.sizeY; j++) {
 		for (i = 0; i < w->cubes.sizeX; i++)
-			(void) printf(" %2d ",(*mat)[ToPosition(i, j)]);
+			(void) printf(" %2d ",(*mat)[toPosition(i, j)]);
 		(void) printf("\n");
 	}
 	(void) printf("\n");
@@ -330,23 +330,23 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 	tmpMatrix[startLoc] = 1;
 	queueTail++;
 
-	/** if the selected element has a distance of zero,
-	 ** we have found it; (This really is not a queue,
-	 ** but rather a range of elements to be searched
-	 ** for an element of the desired properties;
-	 **/
+	/* if the selected element has a distance of zero,
+	 * we have found it; (This really is not a queue,
+	 * but rather a range of elements to be searched
+	 * for an element of the desired properties;
+	 */
 
-	/** as we search for a path,
-	 ** LINK array is used to indicate the direction from which
-	 ** we moved into a location;
-	 ** TMP_MATRIX array is used to keep track of the move number;
-	 **/
+	/* as we search for a path,
+	 * LINK array is used to indicate the direction from which
+	 * we moved into a location;
+	 * TMP_MATRIX array is used to keep track of the move number;
+	 */
 
 	while (queueHead < queueTail && !foundPath) {
-		/** find the entry that
-		 ** (1) has the smallest distance and
-		 ** (2) has the smallest move number;
-		 **/
+		/* find the entry that
+		 * (1) has the smallest distance and
+		 * (2) has the smallest move number;
+		 */
 
 		nextLoc = locQueue[queueHead];
 		nextDist = locDist[queueHead];
@@ -368,16 +368,13 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 		}
 		locQueueUsed[chosen] = True;
 
-		/********************************/
-		/** permute the chosen element **/
-		/********************************/
-
+		/* permute the chosen element */
 		candidate[TOP] = nextUp(nextLoc);
 		candidate[LEFT] = nextLeft(nextLoc);
 		candidate[BOTTOM] = nextDown(nextLoc);
 		candidate[RIGHT] = nextRight(nextLoc);
-		locX = Column(nextLoc);
-		locY = Row(nextLoc);
+		locX = toColumn(nextLoc);
+		locY = toRow(nextLoc);
 		if (locX == 0)
 			candidate[LEFT] = -1;
 		if (locX == w->cubes.sizeX - 1)
@@ -391,11 +388,12 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 			if (candidate[i] != -1 &&
 					tmpMatrix[candidate[i]] == 0) {
 				tmpMatrix[candidate[i]] = moveNum;
-				/** the next line works because the
-				 ** candidate index is same as the
-				 ** direction moved to reach the
-				 ** candidate;
-				 **/
+				/*
+				 * the next line works because the
+				 * candidate index is same as the
+				 * direction moved to reach the
+				 * candidate;
+				 */
 				locList[candidate[i]] = i;
 				locQueue[queueTail] = candidate[i];
 				locDist[queueTail] =
@@ -408,9 +406,7 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 				}
 			}
 
-		/***************************************************/
-		/** delete used items from the front of the queue **/
-		/***************************************************/
+		/* delete used items from the front of the queue */
 		while (locQueueUsed[queueHead] && queueHead < queueTail)
 			queueHead++;
 	}
@@ -425,11 +421,11 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 		intCat(&buf1, "Could not find a way to move ", startLoc);
 		stringCat(&buf2, buf1, " (");
 		free(buf1);
-		intCat(&buf1, buf2, Column(startLoc));
+		intCat(&buf1, buf2, toColumn(startLoc));
 		free(buf2);
 		stringCat(&buf2, buf1, ",");
 		free(buf1);
-		intCat(&buf1, buf2, Row(startLoc));
+		intCat(&buf1, buf2, toRow(startLoc));
 		free(buf2);
 		stringCat(&buf2, buf1, ") to ");
 		free(buf1);
@@ -437,11 +433,11 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 		free(buf2);
 		stringCat(&buf2, buf1, " (");
 		free(buf1);
-		intCat(&buf1, buf2, Column(endLoc));
+		intCat(&buf1, buf2, toColumn(endLoc));
 		free(buf2);
 		stringCat(&buf2, buf1, ",");
 		free(buf1);
-		intCat(&buf1, buf2, Row(endLoc));
+		intCat(&buf1, buf2, toRow(endLoc));
 		free(buf2);
 		stringCat(&buf2, buf1, "), exiting.");
 		free(buf1);
@@ -450,10 +446,11 @@ planMove(CubesWidget w, int startLoc, int endLoc, int **path)
 		return;
 	}
 
-	/** copy the path we found into the path array;
-	 ** element 0 will contain the number of moves in the path;
-	 ** by the time we get there, nextLoc is in the final location
-         **/
+	/*
+	 * copy the path we found into the path array;
+	 * element 0 will contain the number of moves in the path;
+	 * by the time we get there, nextLoc is in the final location
+         */
 
 	(*path)[0] = tmpMatrix[nextLoc] - 1;
 	for (i = (*path)[0]; i > 0; i--) {
@@ -481,7 +478,7 @@ myMoveSpaceTo(CubesWidget w, int loc) {
 	int plan[MAX_PLAN];
 	int *planPtr = &(plan[0]);
 
-	planMove(w, ToPosition(spaceX, spaceY), loc, &planPtr);
+	planMove(w, toPosition(spaceX, spaceY), loc, &planPtr);
 	currentDir = plan[1];
 	for (i = 1; i <= plan[0]; i++) {
 		if (plan[i] == currentDir) {
@@ -498,10 +495,11 @@ myMoveSpaceTo(CubesWidget w, int loc) {
 }
 
 static void
-movePiece(CubesWidget w, int loc, int targetLoc) {
+movePiece(CubesWidget w, int location, int targetLoc) {
 	int i;
 	int plan[MAX_PLAN];
 	int *planPtr = &(plan[0]);
+	int loc = location;
 
 	planMove(w, loc, targetLoc, &planPtr);
 	for (i = 1; i <= plan[0]; i++)
@@ -566,9 +564,9 @@ myFree(void)
 static void
 myInitialize(CubesWidget w)
 {
-	/** Initialize the position and
-	 ** the targetM matrices;
-	 **/
+	/* Initialize the position and
+	 * the targetM matrices;
+	 */
 	int i;
 	int spX, spY;
 
@@ -598,38 +596,40 @@ myInitialize(CubesWidget w)
 	}
 	targetM[w->cubes.sizeRect - 1] = 0;
 
-	/** Move the space into the LR corner of the
-	 ** innermost layer;
-	 ** For each of the outer layers, move the space
-	 ** left one and up one;
-	 **/
+	/*
+	 * Move the space into the LR corner of the
+	 * innermost layer;
+	 * For each of the outer layers, move the space
+	 * left one and up one;
+	 */
 
 	spX = w->cubes.sizeX - 1;
 	spY = w->cubes.sizeY - 1;
 
 	/* Make solution with space at center bottom right */
 	for (i = 0; i < layers - 1; i++) {
-		/** move the space left one; **/
-		targetM[ToPosition(spX, spY)] =
-			targetM[ToPosition((spX - 1), spY)];
-		targetM[ToPosition((spX - 1),spY)] = 0;
+		/* move the space left one; */
+		targetM[toPosition(spX, spY)] =
+			targetM[toPosition((spX - 1), spY)];
+		targetM[toPosition((spX - 1),spY)] = 0;
 		spX -= 1;
 
-		/** move the space up one; **/
-		targetM[ToPosition(spX, spY)] =
-			targetM[ToPosition(spX, (spY - 1))];
-		targetM[ToPosition(spX, (spY - 1))] = 0;
+		/* move the space up one; */
+		targetM[toPosition(spX, spY)] =
+			targetM[toPosition(spX, (spY - 1))];
+		targetM[toPosition(spX, (spY - 1))] = 0;
 		spY -= 1;
 	}
 }
 
-/** To solve this puzzle, work from the outside in;
- ** For each successive ring working your way in,
- **
- ** (1) put the corners in place;
- ** (2) finish off the rest of the boundaries;
- ** (3) do the next layer in;
- **/
+/*
+ * To solve this puzzle, work from the outside in;
+ * For each successive ring working your way in,
+ *
+ * (1) put the corners in place;
+ * (2) finish off the rest of the boundaries;
+ * (3) do the next layer in;
+ */
 
 static void
 solveLayer0(CubesWidget w)
@@ -649,14 +649,15 @@ doLastTwoOnEdge(CubesWidget w, int ntLast, int last, int tmp, int emergency)
 	movePiece(w, findPiece(w, ntLastPiece),last);
 	locked[last] = True;
 
-	/** if the last piece is stuck where the next to the last
-	 ** piece should go, do some magic to fix things up;
-	 **/
+	/*
+	 * if the last piece is stuck where the next to the last
+	 * piece should go, do some magic to fix things up;
+	 */
 	if (findPiece(w, 0) == ntLast)
 		myMoveSpaceTo(w, tmp);
 
 	if (findPiece(w, lastPiece) == ntLast) {
-		/** a rescue is necessary **/
+		/* a rescue is necessary */
 		locked[last] = False;
 		movePiece(w, findPiece(w, ntLastPiece), ntLast);
 		locked[ntLast] = True;
@@ -688,7 +689,7 @@ solveLayer(CubesWidget w, int layer)
 	if (layer == 0) {
 		solveLayer0(w);
 	} else {
-		/** find and put each of the corners into place **/
+		/* find and put each of the corners into place */
 		ul = UL(layer);
 		ur = UR(layer);
 		ll = LL(layer);
@@ -703,21 +704,20 @@ solveLayer(CubesWidget w, int layer)
 		movePiece(w, findPiece(w, targetM[lr]), lr);
 		locked[lr] = True;
 
-		/** Strategy for doing the pieces between the corners:
-		 ** (1) put all but the last two edge pieces in place;
-		 ** (2) put the next to the last piece next to the
-		 **	corner;
-		 ** (3) put the last piece one move in from its final
-		 **	position;
-		 ** (4) move the space to the final position of the
-		 **	next to the last piece;
-		 ** (5) slide the next to the last piece over and the
-		 **	last piece into the edge where it goes.
-		 **/
+		/*
+		 * Strategy for doing the pieces between the corners:
+		 * (1) put all but the last two edge pieces in place;
+		 * (2) put the next to the last piece next to the
+		 *	corner;
+		 * (3) put the last piece one move in from its final
+		 *	position;
+		 * (4) move the space to the final position of the
+		 *	next to the last piece;
+		 * (5) slide the next to the last piece over and the
+		 *	last piece into the edge where it goes.
+		 */
 
-		/**************/
-		/** top edge **/
-		/**************/
+		/* top edge */
 		for (i = ul + 1; i < ur - 2; i++) {
 			movePiece(w, findPiece(w, targetM[i]), i);
 			locked[i] = True;
@@ -729,9 +729,7 @@ solveLayer(CubesWidget w, int layer)
 		emergency = nextDown(tmp);
 		doLastTwoOnEdge(w, ntLast, last, tmp, emergency);
 
-		/*****************/
-		/** bottom edge **/
-		/*****************/
+		/* bottom edge */
 		for (i = ll + 1; i < lr - 2; i++) {
 			movePiece(w, findPiece(w, targetM[i]), i);
 			locked[i] = True;
@@ -743,9 +741,7 @@ solveLayer(CubesWidget w, int layer)
 		emergency = nextUp(tmp);
 		doLastTwoOnEdge(w, ntLast, last, tmp, emergency);
 
-		/***************/
-		/** left side **/
-		/***************/
+		/* left side */
 		for (i = ul + w->cubes.sizeX; i < ll - 2 * w->cubes.sizeX;
 				i += w->cubes.sizeX) {
 			movePiece(w, findPiece(w, targetM[i]), i);
@@ -758,9 +754,7 @@ solveLayer(CubesWidget w, int layer)
 		emergency = nextRight(tmp);
 		doLastTwoOnEdge(w, ntLast, last, tmp, emergency);
 
-		/****************/
-		/** right side **/
-		/****************/
+		/* right side */
 		for (i = ur + w->cubes.sizeX; i < lr - 2 * w->cubes.sizeX;
 				i += w->cubes.sizeX) {
 			movePiece(w, findPiece(w, targetM[i]), i);
@@ -781,12 +775,12 @@ solveRow(CubesWidget w, int row)
 	int i, loc, last, ntLast, tmp, emergency;
 
 	for (i = 0; i < w->cubes.sizeX - 2; i++) {
-		loc = ToPosition(i, row);
+		loc = toPosition(i, row);
 		movePiece(w, findPiece(w, targetM[loc]), loc);
 		locked[loc] = True;
 	}
-	ntLast = ToPosition(w->cubes.sizeX - 2, row);
-	last = ToPosition(w->cubes.sizeX - 1, row);
+	ntLast = toPosition(w->cubes.sizeX - 2, row);
+	last = toPosition(w->cubes.sizeX - 1, row);
 	tmp = last + w->cubes.sizeX;
 	emergency = tmp + w->cubes.sizeX;
 	doLastTwoOnEdge(w, ntLast, last, tmp, emergency);
@@ -798,12 +792,12 @@ solveCol(CubesWidget w, int col)
 	int i, loc, last, ntLast, tmp, emergency;
 
 	for (i = 0; i < w->cubes.sizeY - 2; i++) {
-		loc = ToPosition(col, i);
+		loc = toPosition(col, i);
 		movePiece(w, findPiece(w, targetM[loc]), loc);
 		locked[loc] = True;
 	}
-	ntLast = ToPosition(col, w->cubes.sizeY - 2);
-	last = ToPosition(col, w->cubes.sizeY - 1);
+	ntLast = toPosition(col, w->cubes.sizeY - 2);
+	last = toPosition(col, w->cubes.sizeY - 1);
 	tmp = last + 1;
 	emergency = tmp + 1;
 	doLastTwoOnEdge(w, ntLast, last, tmp, emergency);
@@ -811,7 +805,7 @@ solveCol(CubesWidget w, int col)
 
 /* This procedure coordinates the solution process. */
 void
-SolveSomeBlocks(CubesWidget w)
+solveSomeBlocks(CubesWidget w)
 {
 	int i;
 
@@ -820,33 +814,34 @@ SolveSomeBlocks(CubesWidget w)
 		myInitialize(w);
 	}
         setPuzzle(w, ACTION_RESET);
-	/** determine the position we want to be in when
-	 ** we are done; This position will have the space in
-	 ** the center;  Then, we'll move the space back to
-	 ** the outside.
-	 **/
-	if (SolvingFlag)
+	/*
+	 * determine the position we want to be in when
+	 * we are done; This position will have the space in
+	 * the center;  Then, we'll move the space back to
+	 * the outside.
+	 */
+	if (solvingFlag)
 		return;
 
 #ifdef JMP
 	if (!setjmp(solve_env))
 #endif
 	{
-		SolvingFlag = True;
+		solvingFlag = True;
 		for (i = 0; i < w->cubes.sizeRect; i++)
 			locked[i] = False;
-		/** solve the extra rows and cols **/
+		/* solve the extra rows and cols */
 		for (i = 0; i < extraRows; i++)
 			solveRow(w, i);
 		for (i = 0; i < extraColumns; i++)
 			solveCol(w, i);
 
-		/** solve each layer **/
+		/* solve each layer */
 		for (i = layers - 1; i >= 0; i--) {
 			solveLayer(w, i);
 		}
-		/** move the space back out to the LR corner; **/
-		/** i is the layer the space is moving into **/
+		/* move the space back out to the LR corner; */
+		/* i is the layer the space is moving into */
 		for (i = 1; i < layers; i++) {
 			moveSpace(w, BOTTOM, 1);
 			moveSpace(w, RIGHT, 1);
@@ -854,13 +849,13 @@ SolveSomeBlocks(CubesWidget w)
 	}
 #ifdef JMP
 	else {
-		DrawAllBlocks(w);
+		drawAllBlocks(w);
 	}
-	AbortSolvingFlag = False;
+	abortSolvingFlag = False;
 #endif
 	for (i = 0; i < w->cubes.sizeRect; i++)
 		locked[i] = False;
-	SolvingFlag = False;
+	solvingFlag = False;
 	w->cubes.cheat = True; /* Assume the worst. */
         setPuzzle(w, ACTION_COMPUTED);
 }
