@@ -1,7 +1,7 @@
 /*
  * @(#)xcubes.c
  *
- * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -45,39 +45,39 @@ static const char optionsHelp[] = {
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-"A 3D  sliding block puzzle.  The cubes represented are  "
-"flattened out on the plane.  If the Blocks Z slider  is\n"
-"greater than 1,  then each group of boxes is a layer of the "
+"A 3D sliding block puzzle.  The cubes represented are  "
+"flattened out on the plane.  If the Blocks Z slider is\n"
+"greater than 1, then each group of boxes is a layer of the "
 "puzzle.  If the Blocks Z slider = 1, then this is a\n"
 "simple 15 tile puzzle.  The 15 puzzle was originally made "
 "around 1880 by Noyes Chapman (the 14-15 puzzle of Sam\n"
-"Loyd  was made soon after.)  Similar 3D puzzles include  BloxBox; "
-"Qrazy Qube (2x2x2)  by P. Hein of Denmark and\n"
+"Loyd was made soon after.)  Similar 3D puzzles include BloxBox; "
+"Qrazy Qube (2x2x2) by P. Hein of Denmark and\n"
 "Varikon Box 'L (3x3x3) (Hungary) and Mad Marbles (3x3x3) by "
 "Toys & Games International USA."
 };
 
 static const char featuresHelp[] = {
 "Click \"mouse-left\" button to move a block.  Clicks on "
-"a space, or clicks on blocks  that are not in line\n"
+"a space, or clicks on blocks that are not in line\n"
 "with a space, will not move the blocks.  Notice, one can move "
-"more than  one block at a time by clicking\n"
+"more than one block at a time by clicking\n"
 "on the block farthest from the space but still in line "
 "with the space.  Since you only have a 2-D screen\n"
-"the next level the down is  either the box to the right of "
-"the current box  or the bottom of the current\n"
+"the next level the down is either the box to the right of "
+"the current box or the bottom of the current\n"
 "box.\n"
 "\n"
 "Click \"mouse-right\" button, or press \"C\" or \"c\" "
 "keys, to clear the puzzle.\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"Z\" or \"z\" keys to randomize the puzzle.  New records "
 "can only be set from a cleared state.\n"
@@ -114,11 +114,11 @@ static const char featuresHelp[] = {
 };
 
 static const char referencesHelp[] = {
-"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
-"Mathematics Series), Oxford University Press  1986,\n"
+"L. E. Horden, Sliding Piece Puzzles (Recreations in "
+"Mathematics Series), Oxford University Press 1986,\n"
 "pp 1, 157-159.\n"
 "Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
-"and Solve Them),  University of Washington\n"
+"and Solve Them), University of Washington\n"
 "Press, Seattle 1987, p 126, 127."
 };
 #endif
@@ -157,6 +157,8 @@ static CubesRec widget;
 #include <Xm/PushBG.h>
 #include <Xm/CascadeB.h>
 #include <Xm/Scale.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -204,7 +206,7 @@ static CubesRec widget;
 #define SCOREFILE "cubes.scores"
 #endif
 
-#define MAX_CUBES 8
+#define MAX_BLOCKS 8
 #define NEVER (-1)
 #define FILE_NAME_LENGTH 1024
 #define USER_NAME_LENGTH 120
@@ -218,22 +220,23 @@ typedef struct {
 	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAX_CUBES - MIN_CUBES + 1]
-[MAX_CUBES - MIN_CUBES + 1][MAX_CUBES - MIN_CUBES + 1];
+static PuzzleRecord puzzleRecord[MAX_BLOCKS - MIN_BLOCKS + 1]
+[MAX_BLOCKS - MIN_BLOCKS + 1][MAX_BLOCKS - MIN_BLOCKS + 1];
 static int movesDsp = 0;
 static char messageDsp[MESSAGE_LENGTH] = "Welcome";
 static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 static Widget movesText, recordText, message;
 static Widget blockXSlider, blockYSlider, blockZSlider, speedSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, clearDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static char titleDsp[TITLE_LENGTH] = "";
 #endif
@@ -270,9 +273,9 @@ printRecords(void)
 
 	(void) printf("          CUBES  HALL OF FAME\n\n");
 	(void) printf("   Z   Y   X USER             MOVES\n");
-	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
-		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
-			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
+	for (i = 0; i < MAX_BLOCKS - MIN_BLOCKS + 1; i++)
+		for (j = i; j < MAX_BLOCKS - MIN_BLOCKS + 1; j++)
+			for (k = j; k < MAX_BLOCKS - MIN_BLOCKS + 1; k++) {
 				if (puzzleRecord[k][j][i].score > 0)
 					(void) printf("%4d%4d%4d %-12s%9d\n",
 						i + 1, j + 1, k + 1,
@@ -287,9 +290,9 @@ initRecords(void)
 {
 	int i, j, k;
 
-	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
-		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
-			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
+	for (i = 0; i < MAX_BLOCKS - MIN_BLOCKS + 1; i++)
+		for (j = i; j < MAX_BLOCKS - MIN_BLOCKS + 1; j++)
+			for (k = j; k < MAX_BLOCKS - MIN_BLOCKS + 1; k++) {
 				puzzleRecord[k][j][i].score = puzzleRecord[k][i][j].score =
 					puzzleRecord[j][k][i].score = puzzleRecord[j][i][k].score =
 					puzzleRecord[i][k][j].score = puzzleRecord[i][j][k].score = NEVER;
@@ -354,9 +357,9 @@ readRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
-		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
-			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
+	for (i = 0; i < MAX_BLOCKS - MIN_BLOCKS + 1; i++)
+		for (j = i; j < MAX_BLOCKS - MIN_BLOCKS + 1; j++)
+			for (k = j; k < MAX_BLOCKS - MIN_BLOCKS + 1; k++) {
 				(void) fscanf(fp, "%d %s", &n, userName);
 				if (n <= puzzleRecord[i][j][k].score ||
 						puzzleRecord[i][j][k].score <= NEVER) {
@@ -415,9 +418,9 @@ writeRecords(void)
 #endif
 		}
 #endif
-		for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++) {
-			for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++) {
-				for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++)
+		for (i = 0; i < MAX_BLOCKS - MIN_BLOCKS + 1; i++) {
+			for (j = i; j < MAX_BLOCKS - MIN_BLOCKS + 1; j++) {
+				for (k = j; k < MAX_BLOCKS - MIN_BLOCKS + 1; k++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[i][j][k].score,
 						puzzleRecord[i][j][k].name);
@@ -436,15 +439,16 @@ writeRecords(void)
 static void
 printRecord(int sizeX, int sizeY, int sizeZ)
 {
-	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
+	int i = sizeX - MIN_BLOCKS, j = sizeY - MIN_BLOCKS, k = sizeZ - MIN_BLOCKS;
 
-	if (sizeX > MAX_CUBES || sizeY > MAX_CUBES || sizeZ > MAX_CUBES) {
+	if (sizeX > MAX_BLOCKS || sizeY > MAX_BLOCKS || sizeZ > MAX_BLOCKS) {
 		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
-			puzzleRecord[i][j][k].score, puzzleRecord[i][j][k].name);
+			puzzleRecord[i][j][k].score,
+			puzzleRecord[i][j][k].name);
 	}
 #ifdef HAVE_MOTIF
 	printState(recordText, recordDsp);
@@ -476,9 +480,9 @@ printStatus(char *msg, int nMoves
 static Boolean
 handleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 {
-	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
+	int i = sizeX - MIN_BLOCKS, j = sizeY - MIN_BLOCKS, k = sizeZ - MIN_BLOCKS;
 
-	if (sizeX <= MAX_CUBES && sizeY <= MAX_CUBES && sizeZ <= MAX_CUBES &&
+	if (sizeX <= MAX_BLOCKS && sizeY <= MAX_BLOCKS && sizeZ <= MAX_BLOCKS &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		readRecords();	/* Maybe its been updated by another */
@@ -554,13 +558,13 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (sizeX > MAX_CUBES)
+	if (sizeX > MAX_BLOCKS)
 		XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
 	XmScaleSetValue(blockXSlider, sizeX);
-	if (sizeY > MAX_CUBES)
+	if (sizeY > MAX_BLOCKS)
 		XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
 	XmScaleSetValue(blockYSlider, sizeY);
-	if (sizeZ > MAX_CUBES)
+	if (sizeZ > MAX_BLOCKS)
 		XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
 	XmScaleSetValue(blockZSlider, sizeZ);
 	{
@@ -612,7 +616,8 @@ void
 setPuzzle(CubesWidget w, int reason)
 #else
 static void
-puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData,
+		cubesCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -664,7 +669,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
-			break;
+		break;
 	case ACTION_RESTORE:
 	case ACTION_RESET:
 		movesDsp = 0;
@@ -718,7 +723,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeX > MAX_CUBES)
+		if (sizeX > MAX_BLOCKS)
 			XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
 		XmScaleSetValue(blockXSlider, sizeX);
 #endif
@@ -734,7 +739,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockXSlider, sizeX);
-		if (sizeX >= MAX_CUBES)
+		if (sizeX >= MAX_BLOCKS)
 			XtVaSetValues(blockXSlider, XmNmaximum, sizeX, NULL);
 #endif
 #endif
@@ -748,7 +753,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeY > MAX_CUBES)
+		if (sizeY > MAX_BLOCKS)
 			XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
 		XmScaleSetValue(blockYSlider, sizeY);
 #endif
@@ -764,7 +769,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockYSlider, sizeY);
-		if (sizeY >= MAX_CUBES)
+		if (sizeY >= MAX_BLOCKS)
 			XtVaSetValues(blockYSlider, XmNmaximum, sizeY, NULL);
 #endif
 #endif
@@ -778,7 +783,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeZ > MAX_CUBES)
+		if (sizeZ > MAX_BLOCKS)
 			XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
 		XmScaleSetValue(blockZSlider, sizeZ);
 #endif
@@ -794,7 +799,7 @@ puzzleListener(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockZSlider, sizeZ);
-		if (sizeZ >= MAX_CUBES)
+		if (sizeZ >= MAX_BLOCKS)
 			XtVaSetValues(blockZSlider, XmNmaximum, sizeZ, NULL);
 #endif
 #endif
@@ -943,8 +948,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -992,12 +997,12 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			solvePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
-		case ACTION_UP:
 		case ACTION_RIGHT:
-		case ACTION_DOWN:
 		case ACTION_LEFT:
-		case ACTION_IN:
+		case ACTION_UP:
+		case ACTION_DOWN:
 		case ACTION_OUT:
+		case ACTION_IN:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
@@ -1012,7 +1017,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_INCZ:
 		case ACTION_DECZ:
 			if (movePuzzle(&widget,
-					(int) LOWORD(wParam) - ACTION_DECY,
+					(int) LOWORD(wParam) - ACTION_INCY,
 					TRUE)) {
 				sizePuzzle(&widget);
 				(void) InvalidateRect(hWnd, NULL, TRUE);
@@ -1029,15 +1034,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -1111,10 +1116,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1241,7 +1246,7 @@ speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1249,10 +1254,14 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+#ifndef EXTRA
+	if (val >= ACTION_SPEED)
+		val += ACTION_SOUND - ACTION_SPEED;
+#endif
 	XtVaSetValues(puzzle, XtNmenu, val, NULL);
 }
 
@@ -1268,10 +1277,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1295,11 +1304,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1310,6 +1319,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1323,7 +1383,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1350,12 +1410,15 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, blocksRowCol, speedRowCol, messageRowCol;
+	Widget movesRowCol, sliderRowCol, messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
+	XmString readString, writeString, quitString;
 	XmString undoString, redoString;
 	XmString clearString, randomizeString, solveString;
-	XmString speedString, slowString, soundString;
+#ifdef EXTRA
+	XmString speedString, slowString;
+#endif
+	XmString soundString;
 #endif
 
 	progDsp = argv[0];
@@ -1378,17 +1441,17 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
@@ -1396,18 +1459,22 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "Auto-solve");
+#ifdef EXTRA
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
@@ -1415,8 +1482,10 @@ main(int argc, char **argv)
 	XmStringFree(clearString);
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
@@ -1433,9 +1502,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1446,16 +1515,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	clearDialog = createQuery(topLevel,
@@ -1472,7 +1531,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -1524,48 +1583,43 @@ main(int argc, char **argv)
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
 	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
-	blocksRowCol = XtVaCreateManagedWidget("blocksRowCol",
+	sliderRowCol = XtVaCreateManagedWidget("sliderRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 	blockXSlider = XtVaCreateManagedWidget("blockXSlider",
-		xmScaleWidgetClass, blocksRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks X", 9,
-		XmNminimum, MIN_CUBES,
-		XmNmaximum, MAX_CUBES,
-		XmNvalue, DEFAULT_CUBESX,
+		XmNminimum, MIN_BLOCKS,
+		XmNmaximum, MAX_BLOCKS,
+		XmNvalue, DEFAULT_BLOCKSX,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockXSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) blockXChangeListener, (XtPointer) NULL);
 	blockYSlider = XtVaCreateManagedWidget("blockYSlider",
-		xmScaleWidgetClass, blocksRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Y", 9,
-		XmNminimum, MIN_CUBES,
-		XmNmaximum, MAX_CUBES,
-		XmNvalue, DEFAULT_CUBESY,
+		XmNminimum, MIN_BLOCKS,
+		XmNmaximum, MAX_BLOCKS,
+		XmNvalue, DEFAULT_BLOCKSY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockYSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) blockYChangeListener, (XtPointer) NULL);
 	blockZSlider = XtVaCreateManagedWidget("blockZSlider",
-		xmScaleWidgetClass, blocksRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Z", 9,
-		XmNminimum, MIN_CUBES,
-		XmNmaximum, MAX_CUBES,
-		XmNvalue, DEFAULT_CUBESZ,
+		XmNminimum, MIN_BLOCKS,
+		XmNmaximum, MAX_BLOCKS,
+		XmNvalue, DEFAULT_BLOCKSZ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockZSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) blockZChangeListener, (XtPointer) NULL);
-	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
-		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 1,
-		XmNorientation, XmHORIZONTAL,
-		XmNpacking, XmPACK_COLUMN, NULL);
 	speedSlider = XtVaCreateManagedWidget("speedSlider",
-		xmScaleWidgetClass, speedRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
 		XmNmaximum, MAX_SPEED,
@@ -1618,6 +1672,18 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
