@@ -1,7 +1,7 @@
 /*
  * @(#)Dial.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -275,14 +275,14 @@ drawPointer(DialWidget w, GC gc)
 	sine = sin (w->dial.angle);
 	cosine = cos (w->dial.angle);
 
-	points[0].x = w->dial.center.x - sine * pointerWidth2;
-	points[0].y = w->dial.center.y + cosine * pointerWidth2;
-	points[1].x = w->dial.center.x - cosine * pointerLength;
-	points[1].y = w->dial.center.y - sine * pointerLength;
-	points[2].x = w->dial.center.x + sine * pointerWidth2;
-	points[2].y = w->dial.center.y - cosine * pointerWidth2;
-	points[3].x = w->dial.center.x + cosine * pointerTail;
-	points[3].y = w->dial.center.y + sine * pointerTail;
+	points[0].x = (short) (w->dial.center.x - sine * pointerWidth2);
+	points[0].y = (short) (w->dial.center.y + cosine * pointerWidth2);
+	points[1].x = (short) (w->dial.center.x - cosine * pointerLength);
+	points[1].y = (short) (w->dial.center.y - sine * pointerLength);
+	points[2].x = (short) (w->dial.center.x + sine * pointerWidth2);
+	points[2].y = (short) (w->dial.center.y - cosine * pointerWidth2);
+	points[3].x = (short) (w->dial.center.x + cosine * pointerTail);
+	points[3].y = (short) (w->dial.center.y + sine * pointerTail);
 	points[4].x = points[0].x;
 	points[4].y = points[0].y;
 	if (w->dial.inverseGC[1] == gc)
@@ -330,15 +330,15 @@ moveDial(DialWidget w , int dir)
 			return;
 		tac -= w->dial.factor;
 	}
-	w->dial.val = tac;
+	w->dial.val = (int) tac;
 	tac /= w->dial.factor;
 	if (tac > w->dial.maximum) {
 		tac = w->dial.maximum;
-		w->dial.val = w->dial.factor * tac;
+		w->dial.val = (int) (w->dial.factor * tac);
 	}
 	if (tac < w->dial.minimum) {
 		tac = w->dial.minimum;
-		w->dial.val = w->dial.factor * tac;
+		w->dial.val = (int) (w->dial.factor * tac);
 	}
 	pointerLength = w->dial.dialRadius - w->dial.markerLength - 2;
 	avg = (w->dial.maximum + w->dial.minimum) / 2.0;
@@ -629,8 +629,8 @@ selectDial(DialWidget w, XEvent *event, char **args, int n_args)
 		} else
 			angle = 0;
 		avg = (w->dial.maximum + w->dial.minimum) / 2.0;
-		pos = w->dial.factor * (avg + angle * avg /
-			RADIANS(w->dial.maxDegree / 2.0));
+		pos = (int) (w->dial.factor * (avg + angle * avg /
+			RADIANS(w->dial.maxDegree / 2.0)));
 		if (pos < w->dial.factor * w->dial.minimum)
 			 pos = w->dial.factor * w->dial.minimum;
 		if (pos > w->dial.factor * w->dial.maximum)
