@@ -1,7 +1,7 @@
 /*
  * @(#)xdial.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -71,7 +71,7 @@ static const char aboutHelp[] = {
 #ifdef HAVE_MOTIF
 static Widget tracker;
 static Widget aboutDialog;
-static Arg arg[3];
+static Arg args[3];
 static char *progDsp;
 #endif
 #define FILE_NAME_LENGTH 1024
@@ -165,7 +165,7 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-moveCB(Widget w, void *value, void *clientData)
+moveMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_INCREMENT;
 
@@ -185,11 +185,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -253,15 +253,15 @@ main(int argc, char **argv)
 	XmStringFree(moveString);
 	XtManageChild(menuBar);
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(quitString);
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "move_menu",
-		1, moveCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "moveMenu",
+		1, moveMenuListener,
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		NULL);
