@@ -1033,7 +1033,7 @@ resetPieces(DinoWidget w)
 }
 
 static void
-getPieces(DinoWidget w)
+readPieces(DinoWidget w)
 {
 	FILE *fp;
 	int c, mode, orient, practice, moves;
@@ -1051,7 +1051,7 @@ getPieces(DinoWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1065,7 +1065,7 @@ getPieces(DinoWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1611,8 +1611,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->dino.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -1925,13 +1925,13 @@ randomizePuzzleWithDoubleClick(DinoWidget w
 #endif
 
 void
-getPuzzle(DinoWidget w
+readPuzzle(DinoWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 void
