@@ -1,7 +1,7 @@
 /*
  * @(#)Dino2d.c
  *
- * Copyright 1995 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -99,10 +99,10 @@ static char translations2D[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -133,7 +133,7 @@ static XtActionsRec actionsList2D[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
