@@ -194,10 +194,10 @@ static char translationsGL[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -228,7 +228,7 @@ static XtActionsRec actionsListGL[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -2602,7 +2602,7 @@ normalizePosition(float x, float y)
 	if (y > x && y >= -x)
 		return 2;
 	/* (x < y && x <= -y) */
-		return 3;
+	return 3;
 }
 
 Boolean
@@ -2983,8 +2983,8 @@ initializePuzzleGL(Widget request, Widget renew)
 	w->dino.dim = 4; /* 2 and 3 already taken */
 	for (i = 0; i < MAX_FACES + 2; i++)
 		pickColor(w, i, w->dino.mono, face_material[i]);
-		w->dinoGL.numTurnInc = ((w->dino.delay < MAX_TURN_INC) ?
-			w->dino.delay + 1 : MAX_TURN_INC);
+	w->dinoGL.numTurnInc = ((w->dino.delay < MAX_TURN_INC) ?
+		w->dino.delay + 1 : MAX_TURN_INC);
 	resizePuzzleGL(w);
 }
 #endif
