@@ -1,7 +1,7 @@
 /*
  * @(#)DinoU.c
  *
- * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -207,7 +207,8 @@ scanMoves(FILE *fp, DinoWidget w, int moves)
 		while ((c = getc(fp)) != EOF && c != SYMBOL);
 		(void) fscanf(fp, "%d %d %d %d %d",
 			&face, &position, &direction, &style, &control);
-		movePuzzle(w, face, position, direction, style, control);
+		movePuzzle(w, face, position, direction, style, control,
+			INSTANT);
 	}
 }
 
