@@ -1,7 +1,7 @@
 /*
  * @(#)xdino.c
  *
- * Copyright 1995 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1995 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -72,13 +72,13 @@ static const char featuresHelp[] = {
 "keys, to randomize the puzzle (this must be done first\n"
 "to set a new record).\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
@@ -118,20 +118,21 @@ static const char featuresHelp[] = {
 "Note: Up, Left, Right, and Down only work when the "
 "control key is pressed and there is no analog for\n"
 "Dino3d.\n"
+"\n"
 "Key pad for Dino3d, use must use your intuition (is this "
 "a cop out or what?).  The key pad is defined\n"
 "differently depending on which side of the cube your mouse "
 "is pointing at.\n"
 "\n"
-"Use the alt key and the left mouse button, keypad, or arrow "
-"keys to move the center of the cube.  The 2 opposite\n"
-"corners do not move.\n"
+"Use the alt key and the left mouse button, keypad, or "
+"arrow keys to move the center of the cube.  The 2\n"
+"opposite corners do not move.\n"
 "\n"
 "Use the shift keys and the left mouse button, keypad, "
-"or arrow key to access \"Period 2\" turns from \"Both\" mode,\n"
-"otherwise it assumes \"Period 3\" turning.  Edges turn in "
-"\"Period 2\" and corners turn in \"Period 3\".  The\n"
-"\"Period 2\" mode has extra cuts around the faces.\n"
+"or arrow key to access \"Period 2\" turns from \"Both\"\n"
+"mode, otherwise it assumes \"Period 3\" turning.  Edges "
+"turn in \"Period 2\" and corners turn in \"Period 3\".\n"
+"The \"Period 2\" mode has extra cuts around the faces.\n"
 "\n"
 "Use the control key and the left mouse button, keypad, or "
 "arrow keys to move the whole cube.  This is\n"
@@ -178,6 +179,8 @@ static DinoRec widget;
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #include <Xm/ToggleBG.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -260,6 +263,7 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 static Widget movesText, recordText, message;
@@ -271,9 +275,9 @@ static const char *modeString[] =
 	"Period 2", "Period 3", "Both"
 };
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static Widget shell;
 #endif
@@ -447,7 +451,8 @@ printRecord(int mode, Boolean orient, Boolean practice)
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
-			puzzleRecord[i][j].score, puzzleRecord[i][j].name);
+			puzzleRecord[i][j].score,
+			puzzleRecord[i][j].name);
 	}
 #ifdef HAVE_MOTIF
 	printState(recordText, recordDsp);
@@ -669,7 +674,8 @@ void
 setPuzzle(DinoWidget w, int reason)
 #else
 static void
-puzzleListener(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData,
+		dinoCallbackStruct *callData)
 #endif
 {
 	int mode;
@@ -1158,8 +1164,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -1191,6 +1197,11 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
+		case ACTION_PRACTICE:
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
+			(void) InvalidateRect(hWnd, NULL, TRUE);
+			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
@@ -1198,11 +1209,6 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
-		case ACTION_PRACTICE:
-			practicePuzzle(&widget);
-			sizePuzzle(&widget);
-			(void) InvalidateRect(hWnd, NULL, TRUE);
-			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
@@ -1364,15 +1370,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -1441,10 +1447,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1507,7 +1513,8 @@ puzzleRandomizeListener(Widget w, XtPointer clientData,
 	}
 }
 static void
-modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
+modeToggle(Widget w, int mode,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	Boolean orient, practice;
 
@@ -1594,7 +1601,7 @@ speedChangeListener(Widget w, XtPointer clientData,
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1602,10 +1609,16 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+#ifndef EXTRA
+	if (val >= ACTION_PRACTICE)
+		val += ACTION_RANDOMIZE - ACTION_PRACTICE;
+	if (val >= ACTION_ORIENTIZE)
+		val += ACTION_SOUND - ACTION_ORIENTIZE;
+#endif
 	XtVaSetValues(puzzle2d, XtNmenu, val, NULL);
 }
 
@@ -1621,10 +1634,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1648,11 +1661,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1663,6 +1676,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1676,7 +1740,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1706,11 +1770,17 @@ main(int argc, char **argv)
 	Widget movesRowCol, labelRowCol, radioRowCol, switchRowCol;
 	Widget messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
-	XmString undoString, redoString;
-	XmString clearString, practiceString, randomizeString, solveString;
+	XmString readString, writeString, quitString;
+	XmString undoString, redoString, clearString;
+#ifdef EXTRA
+	XmString practiceString;
+#endif
+	XmString randomizeString, solveString;
+#ifdef EXTRA
 	XmString orientizeString;
-	XmString speedString, slowString, soundString, viewString;
+	XmString speedString, slowString;
+#endif
+	XmString soundString, viewString;
 	unsigned int i;
 #endif
 
@@ -1734,53 +1804,65 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
+#ifdef EXTRA
 	practiceString = XmStringCreateSimple((char *) "Practice");
+#endif
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "Auto-solve");
+#ifdef EXTRA
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
 	viewString = XmStringCreateSimple((char *) "View");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		XmVaPUSHBUTTON, viewString, 'V', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
 	XmStringFree(redoString);
 	XmStringFree(clearString);
+#ifdef EXTRA
 	XmStringFree(practiceString);
+#endif
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(orientizeString);
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	XmStringFree(viewString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
@@ -1798,9 +1880,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1811,16 +1893,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	practiceDialog = createQuery(topLevel,
@@ -1841,7 +1913,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowcol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -2013,6 +2085,18 @@ main(int argc, char **argv)
 #endif
 	XtAddCallback(puzzle3d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
