@@ -1,7 +1,7 @@
 /*
  * @(#)Hexagons.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -83,7 +83,7 @@ static void clearWithQueryPuzzle(HexagonsWidget w,
 	XEvent *event, char **args, int nArgs);
 static void clearWithDoubleClickPuzzle(HexagonsWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(HexagonsWidget w,
+static void readPuzzle(HexagonsWidget w,
 	XEvent *event, char **args, int nArgs);
 static void writePuzzle(HexagonsWidget w,
 	XEvent *event, char **args, int nArgs);
@@ -178,10 +178,10 @@ static char translations[] =
  <Btn3Down>(2+): Clear2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -205,7 +205,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Release", (XtActionProc) releasePuzzle},
 	{(char *) "ClearMaybe", (XtActionProc) clearWithQueryPuzzle},
 	{(char *) "Clear2", (XtActionProc) clearWithDoubleClickPuzzle},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1933,10 +1933,7 @@ movePuzzle(HexagonsWidget w, const int direction, const int control)
 		case TL:
 		case TOP:
 		case TR:
-			if (w->hexagons.sizeY <= MIN_TILES +
-					w->hexagons.corners)
-				return FALSE;
-			reason = ACTION_DECY;
+			reason = ACTION_INCY;
 			break;
 		case RIGHT:
 			reason = ACTION_INCX;
@@ -1944,7 +1941,10 @@ movePuzzle(HexagonsWidget w, const int direction, const int control)
 		case BL:
 		case BOTTOM:
 		case BR:
-			reason = ACTION_INCY;
+			if (w->hexagons.sizeY <= MIN_TILES +
+					w->hexagons.corners)
+				return FALSE;
+			reason = ACTION_DECY;
 			break;
 		case LEFT:
 			if (w->hexagons.sizeX <= MIN_TILES)
@@ -2275,7 +2275,7 @@ randomizeTiles(HexagonsWidget w)
 }
 
 static void
-getTiles(HexagonsWidget w)
+readTiles(HexagonsWidget w)
 {
 	FILE *fp;
 	int c, i, sizeX, sizeY, corners, moves;
@@ -2293,7 +2293,7 @@ getTiles(HexagonsWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2307,7 +2307,7 @@ getTiles(HexagonsWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2819,8 +2819,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->hexagons.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getTiles(w);
+		case ACTION_READ:
+			readTiles(w);
 			break;
 		case ACTION_WRITE:
 			writeTiles(w);
@@ -3291,13 +3291,13 @@ clearWithDoubleClickPuzzle(HexagonsWidget w
 static
 #endif
 void
-getPuzzle(HexagonsWidget w
+readPuzzle(HexagonsWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getTiles(w);
+	readTiles(w);
 }
 
 #ifndef WINVER
