@@ -2,7 +2,7 @@
 /*
  * @(#)Hexagons.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -79,7 +79,7 @@ typedef struct {
 } hexagonsCallbackStruct;
 #endif
 
-#define ACTION_GET 100
+#define ACTION_READ 100
 #define ACTION_WRITE 101
 #define ACTION_EXIT 102
 #define ACTION_HIDE 103
@@ -111,8 +111,8 @@ typedef struct {
 #define ACTION_TL 305
 #define ACTION_INCX 401
 #define ACTION_DECX 404
-#define ACTION_INCY 402
-#define ACTION_DECY 400
+#define ACTION_INCY 400
+#define ACTION_DECY 402
 #define ACTION_DESCRIPTION 900
 #define ACTION_FEATURES 901
 #define ACTION_REFERENCES 902
