@@ -1,7 +1,7 @@
 /*
  * @(#)Mball.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -83,7 +83,7 @@ static void randomizePuzzleWithQuery(MballWidget w,
 	XEvent *event, char **args, int nArgs);
 static void randomizePuzzleWithDoubleClick(MballWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(MballWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(MballWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(MballWidget w, XEvent *event, char **args, int nArgs);
 static void undoPuzzle(MballWidget w, XEvent *event, char **args, int nArgs);
 static void redoPuzzle(MballWidget w, XEvent *event, char **args, int nArgs);
@@ -219,10 +219,10 @@ static char translations[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -268,7 +268,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1817,7 +1817,7 @@ resizePieces(MballWidget w)
 }
 
 static void
-getPieces(MballWidget w)
+readPieces(MballWidget w)
 {
 	FILE *fp;
 	int c, i, wedge, band, orient, practice, moves;
@@ -1835,7 +1835,7 @@ getPieces(MballWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1849,7 +1849,7 @@ getPieces(MballWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1879,7 +1879,7 @@ getPieces(MballWidget w)
 		free(buf2);
 		intCat(&buf2, buf1, MAX_WEDGES);
 		free(buf1);
-			DISPLAY_WARNING(buf2);
+		DISPLAY_WARNING(buf2);
 		free(buf2);
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
@@ -2278,7 +2278,7 @@ getColor(MballWidget w, int wedge)
 			intCat(&buf1, buf2, wedge);
 			free(buf2);
 			DISPLAY_WARNING(buf1);
-			free(buf2);
+			free(buf1);
 		}
 	}
 	if (w->mball.reverse) {
@@ -2402,8 +2402,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->mball.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -2785,13 +2785,13 @@ randomizePuzzleWithDoubleClick(MballWidget w
 static
 #endif
 void
-getPuzzle(MballWidget w
+readPuzzle(MballWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 #ifndef WINVER
