@@ -40,7 +40,7 @@ extern void releasePuzzle(MballWidget w,
 	const int x, const int y, const int shift, const int control);
 extern void practicePuzzle(MballWidget w);
 extern void randomizePuzzle(MballWidget w);
-extern void getPuzzle(MballWidget w);
+extern void readPuzzle(MballWidget w);
 extern void writePuzzle(MballWidget w);
 extern void undoPuzzle(MballWidget w);
 extern void redoPuzzle(MballWidget w);
