@@ -2824,7 +2824,7 @@ solveLat(MballWidget w)
 			f(w, wedge);
 			rSHalfHalf(w);
 			midBand = w->mball.bands / 2;
-			if (w->mball.bands % 2 == 1) {
+			if (w->mball.bands % 2 != 0) {
 				if (w->mball.mballLoc[wedge][0].wedge !=
 						w->mball.mballLoc[wedge][midBand].wedge) {
 					rCW(w, midBand);
