@@ -1,7 +1,7 @@
 /*
  * @(#)Mlink.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -101,7 +101,7 @@ static void randomizePuzzleWithQuery(MlinkWidget w,
 	XEvent *event, char **args, int nArgs);
 static void randomizePuzzleWithDoubleClick(MlinkWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(MlinkWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(MlinkWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(MlinkWidget w, XEvent *event, char **args, int nArgs);
 static void undoPuzzle(MlinkWidget w, XEvent *event, char **args, int nArgs);
 static void redoPuzzle(MlinkWidget w, XEvent *event, char **args, int nArgs);
@@ -171,10 +171,10 @@ static char translations[] =
  <Btn3Down>(2+): RandomizeWithDoubleClick()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -199,7 +199,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "PracticeWithDoubleClick", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeWithQuery", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "RandomizeWithDoubleClick", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1348,17 +1348,17 @@ controlPuzzle(MlinkWidget w, int direction)
 {
 	switch (direction) {
 	case TOP:
-		if (w->mlink.faces <= MIN_FACES)
+		if (w->mlink.faces >= MAX_FACES)
 			return;
-		setPuzzle(w, ACTION_DECY);
+		setPuzzle(w, ACTION_INCY);
 		break;
 	case RIGHT:
 		setPuzzle(w, ACTION_INCX);
 		break;
 	case BOTTOM:
-		if (w->mlink.faces >= MAX_FACES)
+		if (w->mlink.faces <= MIN_FACES)
 			return;
-		setPuzzle(w, ACTION_INCY);
+		setPuzzle(w, ACTION_DECY);
 		break;
 	case LEFT:
 		if (w->mlink.tiles <= MIN_TILES)
@@ -1620,7 +1620,7 @@ resetTiles(MlinkWidget w)
 }
 
 static void
-getTiles(MlinkWidget w)
+readTiles(MlinkWidget w)
 {
 	FILE *fp;
 	int c, i, tiles, faces, middle, orient, practice, moves;
@@ -1638,7 +1638,7 @@ getTiles(MlinkWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1652,7 +1652,7 @@ getTiles(MlinkWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2394,8 +2394,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->mlink.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getTiles(w);
+		case ACTION_READ:
+			readTiles(w);
 			break;
 		case ACTION_WRITE:
 			writeTiles(w);
@@ -2960,13 +2960,13 @@ randomizePuzzleWithDoubleClick(MlinkWidget w
 static
 #endif
 void
-getPuzzle(MlinkWidget w
+readPuzzle(MlinkWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getTiles(w);
+	readTiles(w);
 }
 
 #ifndef WINVER
