@@ -1,7 +1,7 @@
 /*
  * @(#)Mlink.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -91,7 +91,7 @@ typedef struct {
 } mlinkCallbackStruct;
 #endif
 
-#define ACTION_GET 100
+#define ACTION_READ 100
 #define ACTION_WRITE 101
 #define ACTION_EXIT 102
 #define ACTION_HIDE 103
@@ -125,8 +125,8 @@ typedef struct {
 #define ACTION_DOWN 312
 #define ACTION_INCX 401
 #define ACTION_DECX 403
-#define ACTION_INCY 402
-#define ACTION_DECY 400
+#define ACTION_INCY 400
+#define ACTION_DECY 402
 #define ACTION_DESCRIPTION 900
 #define ACTION_FEATURES 901
 #define ACTION_REFERENCES 902
