@@ -1,7 +1,7 @@
 /*
  * @(#)xmlink.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -47,8 +47,8 @@ static const char optionsHelp[] = {
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-"Ideal's The Missing Link, a 4x4 puzzle,  riding on the wave "
-"of Rubik's Cube craze.  There are  many variations on this\n"
+"Ideal's The Missing Link, a 4x4 puzzle, riding on the wave "
+"of Rubik's Cube craze.  There are many variations on this\n"
 "theme, including the \"6x6\" puzzle and Babylon Tower.  What "
 "makes the Missing Link a harder puzzle to solve is that the\n"
 "2 center positions rotate together."
@@ -69,13 +69,13 @@ static const char featuresHelp[] = {
 "keys, to randomize the puzzle (this must be done first\n"
 "to set a new record).\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
@@ -158,6 +158,8 @@ static MlinkRec widget;
 #include <Xm/CascadeB.h>
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -226,6 +228,7 @@ static char messageDsp[MESSAGE_LENGTH] = "Welcome";
 static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 static Widget movesText, recordText, message;
@@ -233,9 +236,9 @@ static Widget orientizeSwitch, middleSwitch, practiceSwitch;
 static Widget tileSlider, faceSlider, speedSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static char titleDsp[TITLE_LENGTH] = "";
 #endif
@@ -595,7 +598,8 @@ void
 setPuzzle(MlinkWidget w, int reason)
 #else
 static void
-puzzleListener(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData,
+		mlinkCallbackStruct *callData)
 #endif
 {
 #ifndef WINVER
@@ -661,7 +665,8 @@ puzzleListener(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
-			(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+			(void) strncpy(recordDsp, "practice",
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			printState(recordText, recordDsp);
 #endif
@@ -723,9 +728,9 @@ puzzleListener(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		XtVaSetValues(w,
 			XtNpractice, practice,
 			XtNstart, False, NULL);
-#endif
 #ifdef HAVE_MOTIF
 		XmToggleButtonSetState(practiceSwitch, practice, True);
+#endif
 #endif
 		break;
 	case ACTION_RANDOMIZE:
@@ -998,8 +1003,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -1071,7 +1076,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				GetStockObject(NULL_PEN));
 			(void) movePuzzleInput(&widget, 0,
 				(int) LOWORD(wParam) - ACTION_SHIFT_UP,
-				!((int) wParam % 2), FALSE);
+				!((int) wParam & 1), FALSE);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case ACTION_UP:
@@ -1097,7 +1102,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		case ACTION_INCY:
 		case ACTION_DECX:
 			movePuzzleInput(&widget, 0,
-				(int) LOWORD(wParam) - ACTION_DECY,
+				(int) LOWORD(wParam) - ACTION_INCY,
 				FALSE, TRUE);
 			sizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
@@ -1113,15 +1118,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -1195,10 +1200,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1296,7 +1301,8 @@ tileChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-faceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+faceChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int tiles, faces = cbs->value, old;
 	Boolean orient, middle, practice;
@@ -1320,7 +1326,8 @@ faceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int tiles, faces;
 	Boolean orient = cbs->set, middle, practice, oldOrient;
@@ -1380,6 +1387,7 @@ practiceToggle(Widget w, XtPointer clientData,
 	int tiles, faces;
 	Boolean orient, middle, practice = cbs->set, oldPract;
 
+	
 	XtVaGetValues(puzzle,
 		XtNtiles, &tiles,
 		XtNfaces, &faces,
@@ -1417,7 +1425,7 @@ speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1425,10 +1433,16 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+#ifndef EXTRA
+	if (val >= ACTION_PRACTICE)
+		val += ACTION_RANDOMIZE - ACTION_PRACTICE;
+	if (val >= ACTION_ORIENTIZE)
+		val += ACTION_SOUND - ACTION_ORIENTIZE;
+#endif
 	XtVaSetValues(puzzle, XtNmenu, val, NULL);
 }
 
@@ -1444,10 +1458,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1471,11 +1485,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1486,6 +1500,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1499,7 +1564,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1526,14 +1591,20 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, tilesRowCol, speedRowCol, switchRowCol;
+	Widget movesRowCol, sliderRowCol, switchRowCol;
 	Widget messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
-	XmString undoString, redoString;
-	XmString clearString, practiceString, randomizeString, solveString;
+	XmString readString, writeString, quitString;
+	XmString undoString, redoString, clearString;
+#ifdef EXTRA
+	XmString practiceString;
+#endif
+	XmString randomizeString, solveString;
+#ifdef EXTRA
 	XmString orientizeString, middleString;
-	XmString speedString, slowString, soundString;
+	XmString speedString, slowString;
+#endif
+	XmString soundString;
 #endif
 
 	progDsp = argv[0];
@@ -1556,54 +1627,66 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
+#ifdef EXTRA
 	practiceString = XmStringCreateSimple((char *) "Practice");
+#endif
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "Auto-solve");
+#ifdef EXTRA
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	middleString = XmStringCreateSimple((char *) "Middle");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, middleString, 'M', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
 	XmStringFree(redoString);
 	XmStringFree(clearString);
+#ifdef EXTRA
 	XmStringFree(practiceString);
+#endif
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(orientizeString);
 	XmStringFree(middleString);
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
@@ -1620,9 +1703,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1633,16 +1716,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	practiceDialog = createQuery(topLevel,
@@ -1663,7 +1736,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -1715,13 +1788,13 @@ main(int argc, char **argv)
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
 	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
-	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
+	sliderRowCol = XtVaCreateManagedWidget("sliderRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 	tileSlider = XtVaCreateManagedWidget("tileSlider",
-		xmScaleWidgetClass, tilesRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Tiles", 6,
 		XmNminimum, MIN_TILES,
 		XmNmaximum, MAX_TILES,
@@ -1731,7 +1804,7 @@ main(int argc, char **argv)
 	XtAddCallback(tileSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
 	faceSlider = XtVaCreateManagedWidget("faceSlider",
-		xmScaleWidgetClass, tilesRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Faces", 6,
 		XmNminimum, MIN_FACES,
 		XmNmaximum, MAX_FACES,
@@ -1740,13 +1813,8 @@ main(int argc, char **argv)
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(faceSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) faceChangeListener, (XtPointer) NULL);
-	speedRowCol = XtVaCreateManagedWidget("speedRowCol",
-		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 1,
-		XmNorientation, XmHORIZONTAL,
-		XmNpacking, XmPACK_COLUMN, NULL);
 	speedSlider = XtVaCreateManagedWidget("speedSlider",
-		xmScaleWidgetClass, speedRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
 		XmNmaximum, MAX_SPEED,
@@ -1819,6 +1887,18 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
