@@ -79,7 +79,7 @@ static void randomizePuzzle(OctWidget w,
 	XEvent *event, char **args, int nArgs);
 static void randomizePuzzleWithDoubleClick(OctWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(OctWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(OctWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(OctWidget w, XEvent *event, char **args, int nArgs);
 static void undoPuzzle(OctWidget w, XEvent *event, char **args, int nArgs);
 static void redoPuzzle(OctWidget w, XEvent *event, char **args, int nArgs);
@@ -186,10 +186,10 @@ static char translations[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -224,7 +224,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -2080,7 +2080,7 @@ resizePieces(OctWidget w)
 }
 
 static void
-getPieces(OctWidget w)
+readPieces(OctWidget w)
 {
 	FILE *fp;
 	int c, i, size, mode, sticky, orient, practice, moves;
@@ -2098,7 +2098,7 @@ getPieces(OctWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2112,7 +2112,7 @@ getPieces(OctWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2728,8 +2728,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->oct.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -3095,13 +3095,13 @@ randomizePuzzleWithDoubleClick(OctWidget w
 static
 #endif
 void
-getPuzzle(OctWidget w
+readPuzzle(OctWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 #ifndef WINVER
