@@ -1,7 +1,7 @@
 /*
  * @(#)Oct.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -82,7 +82,7 @@ typedef struct {
 } octCallbackStruct;
 #endif
 
-#define ACTION_GET 100
+#define ACTION_READ 100
 #define ACTION_WRITE 101
 #define ACTION_EXIT 102
 #define ACTION_HIDE 103
