@@ -40,7 +40,7 @@ extern void releasePuzzle(OctWidget w,
 	const int x, const int y, const int shift, const int control);
 extern void practicePuzzle(OctWidget w);
 extern void randomizePuzzle(OctWidget w);
-extern void getPuzzle(OctWidget w);
+extern void readPuzzle(OctWidget w);
 extern void writePuzzle(OctWidget w);
 extern void undoPuzzle(OctWidget w);
 extern void redoPuzzle(OctWidget w);
