@@ -71,7 +71,7 @@ static void releasePuzzle(PanexWidget w,
 static void clearWithQueryPuzzle(PanexWidget w,
 	XEvent *event, char **args, int nArgs);
 static void clearWithDoubleClickPuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
-static void getPuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
+static void readPuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
 static void writePuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
 static void undoPuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
 static void redoPuzzle(PanexWidget w, XEvent *event, char **args, int nArgs);
@@ -106,10 +106,10 @@ static char translations[] =
  <Btn1Up>: Release()\n\
  <Btn3Down>: ClearMaybe()\n\
  <Btn3Down>(2+): Clear2()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>s: Solve()\n\
  <KeyPress>i: Increment()\n\
@@ -127,7 +127,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Release", (XtActionProc) releasePuzzle},
 	{(char *) "ClearMaybe", (XtActionProc) clearWithQueryPuzzle},
 	{(char *) "Clear2", (XtActionProc) clearWithDoubleClickPuzzle},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1263,7 +1263,7 @@ resetTiles(PanexWidget w)
 }
 
 static void
-getTiles(PanexWidget w)
+readTiles(PanexWidget w)
 {
 	FILE *fp;
 	int c, i, tiles, mode, moves;
@@ -1281,7 +1281,7 @@ getTiles(PanexWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1295,7 +1295,7 @@ getTiles(PanexWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1923,8 +1923,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->panex.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getTiles(w);
+		case ACTION_READ:
+			readTiles(w);
 			break;
 		case ACTION_WRITE:
 			writeTiles(w);
@@ -2390,13 +2390,13 @@ clearWithDoubleClickPuzzle(PanexWidget w
 #endif
 
 void
-getPuzzle(PanexWidget w
+readPuzzle(PanexWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getTiles(w);
+	readTiles(w);
 }
 
 void
