@@ -37,7 +37,7 @@ extern void hidePuzzle(PanexWidget w);
 extern void selectPuzzle(PanexWidget w, const int x);
 extern void motionPuzzle(PanexWidget w, const int x);
 extern void releasePuzzle(PanexWidget w, const int x);
-extern void getPuzzle(PanexWidget w);
+extern void readPuzzle(PanexWidget w);
 extern void writePuzzle(PanexWidget w);
 extern void undoPuzzle(PanexWidget w);
 extern void redoPuzzle(PanexWidget w);
