@@ -77,7 +77,7 @@ static void randomizePuzzleWithQuery(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
 static void randomizePuzzleWithDoubleClick(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(PyraminxWidget w,
+static void readPuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
 static void writePuzzle(PyraminxWidget w,
 	XEvent *event, char **args, int nArgs);
@@ -194,10 +194,10 @@ static char translations[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -230,7 +230,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1995,7 +1995,7 @@ resizePieces(PyraminxWidget w)
 }
 
 static void
-getPieces(PyraminxWidget w)
+readPieces(PyraminxWidget w)
 {
 	FILE *fp;
 	int c, i, size, mode, sticky, orient, practice, moves;
@@ -2013,7 +2013,7 @@ getPieces(PyraminxWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2027,7 +2027,7 @@ getPieces(PyraminxWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2616,8 +2616,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->pyraminx.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -2992,13 +2992,13 @@ randomizePuzzleWithDoubleClick(PyraminxWidget w
 static
 #endif
 void
-getPuzzle(PyraminxWidget w
+readPuzzle(PyraminxWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 #ifndef WINVER
