@@ -1,7 +1,7 @@
 /*
  * @(#)PyraminxP.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -40,7 +40,7 @@ extern void releasePuzzle(PyraminxWidget w,
 	const int x, const int y, const int shift, const int control);
 extern void practicePuzzle(PyraminxWidget w);
 extern void randomizePuzzle(PyraminxWidget w);
-extern void getPuzzle(PyraminxWidget w);
+extern void readPuzzle(PyraminxWidget w);
 extern void writePuzzle(PyraminxWidget w);
 extern void undoPuzzle(PyraminxWidget w);
 extern void redoPuzzle(PyraminxWidget w);
