@@ -1,7 +1,7 @@
 /*
  * @(#)xpyraminx.c
  *
- * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -51,7 +51,7 @@ static const char descriptionHelp[] = {
 "Meffert and called the Pyraminx.  This has 2^5*3^8*6!/2\n"
 "or 75,582,720 different combinations.\n"
 "Another puzzle Senior Pyraminx 3x3x3 exists only on "
-"paper, it has period 2 turning (i.e.  edges turn with\n"
+"paper, it has period 2 turning (i.e. edges turn with\n"
 "180 degree intervals) but the corners would fall off "
 "unless it had some tricky mechanism.  (This may be the\n"
 "same as the Master Pyraminx which has 446,965,972,992,000 "
@@ -92,18 +92,18 @@ static const char featuresHelp[] = {
 "keys, to randomize the puzzle (this must be done first\n"
 "to set a new record).\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
 "Press \"S\" or \"s\" keys to start auto-solver.  Only works on "
-"1x1x1, 2x2x2, and 3x3x3 pyrmaminxs in Period 3 mode.\n"
+"1x1x1, 2x2x2, and 3x3x3 facets in Period 3 mode.\n"
 "\n"
 "Press \"O\" or \"o\" keys to toggle the orient mode.  One "
 "has to orient the faces in orient mode, besides\n"
@@ -119,9 +119,9 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"Y\" or \"y\" keys to toggle sticky mode (increase/decrease "
 "is disabled here if sticky mode is on).\n"
-"\"Sticky\" and \"Period 2\" turning allows only the edges to "
-"turn, and the 2 center rows turn together. It is as if\n"
-"the middle cut of the three cuts did not exist.\n"
+"\"Sticky\" and \"Period 2\" turning allows only the edges "
+"to turn, and the 2 center rows turn together. It is\n"
+"as if the middle cut of the three cuts did not exist.\n"
 "\"Sticky\" and \"Period 3\" turning allows only the faces to "
 "turn, it is as if the middle cut of the three cuts\n"
 "did not exist.\n"
@@ -150,14 +150,15 @@ static const char featuresHelp[] = {
 "4<5>6  Left, Clockwise, Right\n"
 "  v\n"
 "1 2    Lower Left, Down\n"
+"\n"
 "Use the shift keys to access \"Period 3\" turns from "
 "\"Both\" mode, otherwise it assumes \"Period 2\" turning.\n"
 "Faces and points turn in \"Period 3\" and edges (2 points) "
 "turn in \"Period 2\".\n"
 "\n"
-"Use the control key and the left mouse button, keypad, or "
-"arrow keys to move the whole tetrahedron.  This is not\n"
-"recorded as a turn."
+"Use the control key and the left mouse button, keypad, "
+"or arrow keys to move the whole tetrahedron.  This\n"
+"is not recorded as a turn."
 };
 
 static const char referencesHelp[] = {
@@ -210,6 +211,8 @@ static PyraminxRec widget;
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #include <Xm/ToggleBG.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -278,6 +281,7 @@ static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 #define MULTSPEED 20
@@ -290,9 +294,9 @@ static const char *modeString[] =
 	"Period 2", "Period 3", "Both"
 };
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static char titleDsp[TITLE_LENGTH] = "";
 #endif
@@ -1045,8 +1049,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -1080,6 +1084,11 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			clearPuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+		case ACTION_PRACTICE:
+			practicePuzzle(&widget);
+			sizePuzzle(&widget);
+			(void) InvalidateRect(hWnd, NULL, TRUE);
+			break;
 		case ACTION_RANDOMIZE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
@@ -1087,11 +1096,6 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			randomizePuzzle(&widget);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
-		case ACTION_PRACTICE:
-			practicePuzzle(&widget);
-			sizePuzzle(&widget);
-			(void) InvalidateRect(hWnd, NULL, TRUE);
-			break;
 		case ACTION_SOLVE:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
@@ -1211,15 +1215,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -1289,10 +1293,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1355,7 +1359,8 @@ puzzleRandomizeListener(Widget w, XtPointer clientData,
 }
 
 static void
-pieceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
+pieceChangeListener(Widget w, XtPointer clientData,
+		XmScaleCallbackStruct *cbs)
 {
 	int size = cbs->value, mode;
 	Boolean orient, sticky, practice;
@@ -1382,7 +1387,8 @@ pieceChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 }
 
 static void
-modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
+modeToggle(Widget w, int mode,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int size;
 	Boolean orient, sticky, practice;
@@ -1405,7 +1411,8 @@ modeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 }
 
 static void
-orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+orientToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
 	Boolean orient = cbs->set, sticky, practice;
@@ -1426,7 +1433,8 @@ orientToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 }
 
 static void
-stickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
+stickyToggle(Widget w, XtPointer clientData,
+		XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
 	Boolean orient, sticky = cbs->set, practice;
@@ -1461,16 +1469,19 @@ practiceToggle(Widget w, XtPointer clientData,
 		XmToggleButtonCallbackStruct *cbs)
 {
 	int size, mode;
-	Boolean orient, sticky, practice = cbs->set;
+	Boolean orient, sticky, practice = cbs->set, oldPract;
 
-	XtVaSetValues(puzzle,
-		XtNpractice, practice,
-		XtNstart, False, NULL);
 	XtVaGetValues(puzzle,
 		XtNsize, &size,
 		XtNmode, &mode,
 		XtNorient, &orient,
-		XtNsticky, &sticky, NULL);
+		XtNsticky, &sticky,
+		XtNpractice, &oldPract, NULL);
+	if (oldPract == practice)
+		return;
+	XtVaSetValues(puzzle,
+		XtNpractice, practice,
+		XtNstart, False, NULL);
 	movesDsp = 0;
 	(void) sprintf(buff, "%d", movesDsp);
 	printState(movesText, buff);
@@ -1497,7 +1508,7 @@ speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1505,10 +1516,16 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+#ifndef EXTRA
+	if (val >= ACTION_PRACTICE)
+		val += ACTION_RANDOMIZE - ACTION_PRACTICE;
+	if (val >= ACTION_INCREMENT)
+		val += ACTION_SOUND - ACTION_INCREMENT;
+#endif
 	XtVaSetValues(puzzle, XtNmenu, val, NULL);
 }
 
@@ -1524,10 +1541,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1551,11 +1568,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1566,6 +1583,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1579,7 +1647,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1606,15 +1674,21 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, facetRowCol, labelRowCol, radioRowCol;
+	Widget movesRowCol, sliderRowCol, labelRowCol, radioRowCol;
 	Widget switchRowCol, messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
-	XmString undoString, redoString;
-	XmString clearString, randomizeString, practiceString, solveString;
+	XmString readString, writeString, quitString;
+	XmString undoString, redoString, clearString;
+#ifdef EXTRA
+	XmString practiceString;
+#endif
+	XmString randomizeString, solveString;
+#ifdef EXTRA
 	XmString incrementString, decrementString;
 	XmString orientizeString, stickyString;
-	XmString speedString, slowString, soundString;
+	XmString speedString, slowString;
+#endif
+	XmString soundString;
 	unsigned int i;
 #endif
 
@@ -1638,60 +1712,72 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
+#ifdef EXTRA
 	practiceString = XmStringCreateSimple((char *) "Practice");
+#endif
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "Auto-solve");
+#ifdef EXTRA
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	stickyString = XmStringCreateSimple((char *) "Sticky");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, stickyString, 'y', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
 	XmStringFree(redoString);
 	XmStringFree(clearString);
+#ifdef EXTRA
 	XmStringFree(practiceString);
+#endif
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
 	XmStringFree(orientizeString);
 	XmStringFree(stickyString);
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
@@ -1708,9 +1794,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1721,16 +1807,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	practiceDialog = createQuery(topLevel,
@@ -1751,7 +1827,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -1803,13 +1879,13 @@ main(int argc, char **argv)
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
 	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
-	facetRowCol = XtVaCreateManagedWidget("facetRowCol",
+	sliderRowCol = XtVaCreateManagedWidget("sliderRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 	facetSlider = XtVaCreateManagedWidget("facetSlider",
-		xmScaleWidgetClass, facetRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
 		XmNminimum, MIN_FACETS,
 		XmNmaximum, MAX_FACETS,
@@ -1819,7 +1895,7 @@ main(int argc, char **argv)
 	XtAddCallback(facetSlider, XmNvalueChangedCallback,
 		(XtCallbackProc) pieceChangeListener, (XtPointer) NULL);
 	speedSlider = XtVaCreateManagedWidget("speedSlider",
-		xmScaleWidgetClass, facetRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
 		XmNmaximum, MAX_SPEED,
@@ -1910,6 +1986,18 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
