@@ -917,7 +917,7 @@ resetPieces(RubikWidget w)
 }
 
 static void
-getPieces(RubikWidget w)
+readPieces(RubikWidget w)
 {
 	FILE *fp;
 	int c, i, sizex, sizey, sizez, orient, practice, moves;
@@ -935,7 +935,7 @@ getPieces(RubikWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -949,7 +949,7 @@ getPieces(RubikWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1546,8 +1546,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->rubik.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -1854,13 +1854,13 @@ randomizePuzzleWithDoubleClick(RubikWidget w
 #endif
 
 void
-getPuzzle(RubikWidget w
+readPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 void
