@@ -105,10 +105,10 @@ static char translations3D[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -143,7 +143,7 @@ static XtActionsRec actionsList3D[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -919,7 +919,7 @@ resizePieces(Rubik3DWidget w)
 Boolean
 selectPieces3D(Rubik3DWidget w, int x, int y, int *face, int *position)
 {
-	int u, v, front, tl, ur, ul, i, j;
+	int u, v, front, tl, ur, ul, i = 0, j = 0;
 	int tempx = x, tempy = y, sizeOfRow, sizeOfColumn;
 
 	if (w->rubik.vertical) {
