@@ -1,7 +1,7 @@
 /*
  * @(#)RubikP.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -180,7 +180,7 @@ extern void randomizePuzzleWithDoubleClick(RubikWidget w
 , XEvent *event, char **args, int nArgs
 );
 #endif
-extern void getPuzzle(RubikWidget w
+extern void readPuzzle(RubikWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
