@@ -8,7 +8,7 @@
  * Taken from the algorithm in the Ideal Solution book.
  * Break ability taken from the X puzzle by Don Bennett, HP Labs
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -218,10 +218,12 @@ findCorner(RubikWidget w, int color1, int color2, int color3)
 
 	do {
 		if (colorSide(w, 5, 6) == color1) {
-			if (colorSide(w, 1, 0) == color2 && colorSide(w, 4, 2) == color3)
+			if (colorSide(w, 1, 0) == color2 &&
+					colorSide(w, 4, 2) == color3)
 				corner = temp;
 		} else if (colorSide(w, 5, 6) == color2) {
-			if (colorSide(w, 1, 0) == color3 && colorSide(w, 4, 2) == color1)
+			if (colorSide(w, 1, 0) == color3 &&
+					colorSide(w, 4, 2) == color1)
 				corner = temp;
 		} else if (colorSide(w, 5, 6) == color3 &&
 				colorSide(w, 1, 0) == color1 &&
@@ -1382,5 +1384,6 @@ solveSomePieces(RubikWidget w)
 #endif
 	solvingFlag = False;
 	w->rubik.cheat = True; /* Assume the worst. */
+	setPuzzle(w, ACTION_CHEAT);
 	setPuzzle(w, ACTION_COMPUTED);
 }
