@@ -1,7 +1,7 @@
 /*
  * @(#)xrubik.c
  *
- * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -44,12 +44,12 @@ static const char optionsHelp[] = {
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-"The original puzzle  has 9 squares per face  (size = 3).  "
-"The puzzle was  designed by Erno Rubik and called the\n"
+"The original puzzle has 9 squares per face (size = 3).  "
+"The puzzle was designed by Erno Rubik and called the\n"
 "Rubik's Cube.  This has 8!*12!*3^8*2^12/12 or 4.3 * 10^19 "
 "different combinations.\n"
-"The Pocket Cube  has 4 squares per face  (size = 2) also "
-"designed by  Erno Rubik.  This has 7!*3^6 or 3,674,160\n"
+"The Pocket Cube has 4 squares per face (size = 2) also "
+"designed by Erno Rubik.  This has 7!*3^6 or 3,674,160\n"
 "different combinations.\n"
 "Rubik's Revenge has 16 squares per face (size = 4) also "
 "designed by Erno Rubik.  This has 7!*3^6*24!*24!/(4!)^6\n"
@@ -60,8 +60,8 @@ static const char descriptionHelp[] = {
 "(8!)^2/4 or 406,425,600 combinations.\n"
 "A physical 6x6x6 cube is possible but to my knowledge no "
 "one has been too successful in building one.  7x7x7 is\n"
-"also possible, but here one  must make the center most "
-"cubes smaller than the  outside cubes, so the corners do\n"
+"also possible, but here one must make the center most "
+"cubes smaller than the outside cubes, so the corners do\n"
 "not fall off when turned."
 };
 
@@ -72,7 +72,7 @@ static const char featuresHelp[] = {
 "where the mouse button was released.\n"
 "\n"
 "Click \"mouse-center\" button, or press \"P\" or \"p\" "
-"keys, to toggle the practice mode  (in practice mode\n"
+"keys, to toggle the practice mode (in practice mode\n"
 "the record should say \"practice\").  This is good for "
 "learning moves and experimenting.\n"
 "\n"
@@ -80,25 +80,25 @@ static const char featuresHelp[] = {
 "keys, to randomize the puzzle (this must be done first\n"
 "to set a new record).\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"C\" or \"c\" keys to clear the puzzle.\n"
 "\n"
 "Press \"S\" or \"s\" keys to start auto-solver.  Only works "
 "on 1x1x1, 2x2x2, and 3x3x3 cubes.\n"
 "\n"
-"Press \"O\" or \"o\" keys to toggle  the orient mode.  One "
-"has to  orient the faces in orient mode, besides\n"
-"getting all  the faces to be the  same color.  To do this "
-"one  has to get the  lines to be  oriented in\n"
-"the same direction,  this only matters  with center "
-"piece,  if at all (i.e.  those that are not on a\n"
+"Press \"O\" or \"o\" keys to toggle the orient mode.  One "
+"has to orient the faces in orient mode, besides\n"
+"getting all the faces to be the same color.  To do this "
+"one has to get the lines to be oriented in\n"
+"the same direction, this only matters with center "
+"piece, if at all (i.e. those that are not on a\n"
 "corner or edge).  This does add complexity so there are "
 "2 sets of records.\n"
 "\n"
@@ -144,10 +144,11 @@ static const char featuresHelp[] = {
 "4<5>6  Left, Clockwise, Right\n"
 "  v\n"
 "  2    Down\n"
+"\n"
 "Key pad for Rubik3d, use must use your intuition (is this "
-"a cop out or what?).  The key pad  is defined\n"
-"differently  depending on which side  of the cube your mouse "
-"is pointing at.  One thing  that stays the\n"
+"a cop out or what?).  The key pad is defined\n"
+"differently depending on which side of the cube your mouse "
+"is pointing at.  One thing that stays the\n"
 "same is \"5\" is Clockwise and \"/\" is Counterclockwise.\n"
 "\n"
 "Use the control key and the left mouse button, keypad, or "
@@ -203,6 +204,8 @@ static RubikRec widget;
 #include <Xm/CascadeB.h>
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -287,6 +290,7 @@ static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
 static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 static Widget movesText, recordText, message;
@@ -294,9 +298,9 @@ static Widget cubesXSlider, cubesYSlider, cubesZSlider, speedSlider;
 static Widget orientizeSwitch, practiceSwitch;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static Widget shell;
 #endif
@@ -747,7 +751,8 @@ void
 setPuzzle(RubikWidget w, int reason)
 #else
 static void
-puzzleListener(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
+puzzleListener(Widget w, caddr_t clientData,
+		rubikCallbackStruct *callData)
 #endif
 {
 	int sizex, sizey, sizez;
@@ -1346,8 +1351,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -1516,15 +1521,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -1593,10 +1598,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1812,7 +1817,7 @@ speedChangeListener(Widget w, XtPointer clientData,
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1820,10 +1825,16 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+#ifndef EXTRA
+	if (val >= ACTION_PRACTICE)
+		val += ACTION_RANDOMIZE - ACTION_PRACTICE;
+	if (val >= ACTION_INCREMENT)
+		val += ACTION_SOUND - ACTION_INCREMENT;
+#endif
 	XtVaSetValues(puzzle2d, XtNmenu, val, NULL);
 }
 
@@ -1839,10 +1850,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1866,11 +1877,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1881,6 +1892,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1894,7 +1956,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1923,11 +1985,17 @@ main(int argc, char **argv)
 	Widget menuBarPanel, mainPanel, controlPanel;
 	Widget movesRowCol, cubesRowCol, switchRowCol, messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
-	XmString undoString, redoString;
-	XmString clearString, randomizeString, practiceString, solveString;
+	XmString readString, writeString, quitString;
+	XmString undoString, redoString, clearString;
+#ifdef EXTRA
+	XmString practiceString;
+#endif
+	XmString randomizeString, solveString;
+#ifdef EXTRA
 	XmString incrementString, decrementString, orientizeString;
-	XmString speedString, slowString, soundString, viewString;
+	XmString speedString, slowString;
+#endif
+	XmString soundString, viewString;
 #endif
 
 	progDsp = argv[0];
@@ -1950,59 +2018,71 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
+#ifdef EXTRA
 	practiceString = XmStringCreateSimple((char *) "Practice");
+#endif
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "Auto-solve");
+#ifdef EXTRA
 	incrementString = XmStringCreateSimple((char *) "Increment Size");
 	decrementString = XmStringCreateSimple((char *) "Decrement Size");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
 	viewString = XmStringCreateSimple((char *) "View");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		XmVaPUSHBUTTON, viewString, 'V', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
 	XmStringFree(redoString);
 	XmStringFree(clearString);
+#ifdef EXTRA
 	XmStringFree(practiceString);
+#endif
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
 	XmStringFree(orientizeString);
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	XmStringFree(viewString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
@@ -2020,9 +2100,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -2033,16 +2113,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	practiceDialog = createQuery(topLevel,
@@ -2063,7 +2133,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -2249,6 +2319,18 @@ main(int argc, char **argv)
 #endif
 	XtAddCallback(puzzle3d, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize();
 	XtRealizeWidget(topLevel);
 #ifndef HAVE_MOTIF
