@@ -1084,7 +1084,7 @@ resetPieces(SkewbWidget w)
 }
 
 static void
-getPieces(SkewbWidget w)
+readPieces(SkewbWidget w)
 {
 	FILE *fp;
 	int c, orient, practice, moves;
@@ -1102,7 +1102,7 @@ getPieces(SkewbWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1116,7 +1116,7 @@ getPieces(SkewbWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1638,8 +1638,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->skewb.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getPieces(w);
+		case ACTION_READ:
+			readPieces(w);
 			break;
 		case ACTION_WRITE:
 			writePieces(w);
@@ -1965,13 +1965,13 @@ randomizePuzzleWithDoubleClick(SkewbWidget w
 #endif
 
 void
-getPuzzle(SkewbWidget w
+readPuzzle(SkewbWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getPieces(w);
+	readPieces(w);
 }
 
 void
