@@ -105,10 +105,10 @@ static char translations3D[] =
  <Btn3Down>(2+): Randomize2()\n\
  <Btn4Down>: MoveTop()\n\
  <Btn5Down>: MoveBottom()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -138,7 +138,7 @@ static XtActionsRec actionsList3D[] =
 	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
 	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
 	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
