@@ -391,7 +391,8 @@ setFirstCorner(SkewbWidget w)
 			movePuzzlePiece(w, 0, 1, TR, FALSE);
 			movePuzzlePiece(w, 0, 2, TL, FALSE);
 			movePuzzlePiece(w, 0, 1, BL, FALSE);
-		} else*/ if (i == 5) {
+		} else*/
+		if (i == 5) {
 			movePuzzlePiece(w, 0, 0, BR, FALSE);
 		} else if (i == 6) {
 			movePuzzlePiece(w, 0, 0, TL, FALSE);
@@ -456,7 +457,8 @@ setSecondCorner(SkewbWidget w)
 			movePuzzlePiece(w, 0, 2, TL, FALSE);
 			movePuzzlePiece(w, 0, 1, TR, FALSE);
 			movePuzzlePiece(w, 0, 2, BR, FALSE);
-		} else*/ if (i == 1) {
+		} else*/
+		if (i == 1) {
 			movePuzzlePiece(w, 0, 3, BL, FALSE);
 		} else if (i == 2) {
 			movePuzzlePiece(w, 0, 3, TR, FALSE);
