@@ -1286,7 +1286,7 @@ readThreeD(ThreeDWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
