@@ -109,9 +109,11 @@ typedef struct {
 #define ACTION_DODECA 303
 #define ACTION_ICOSA 304
 #define ACTION_RHOMBIC 305
-#define ACTION_CONTA 306
-#define ACTION_CUBES 307
-#define ACTION_F16 308
+#define ACTION_TRIACONTA 306
+#define ACTION_STAR 307
+#define ACTION_PYRAMID 308
+#define ACTION_BOXES 309
+#define ACTION_F16 310
 #define ACTION_DISTXI 400
 #define ACTION_DISTXD 401
 #define ACTION_DISTYI 402
