@@ -1,7 +1,7 @@
 /*
  * @(#)xthreed.c
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -32,7 +32,7 @@ static const char aboutHelp[] = {
 "in the \"The C Users Journal\"."
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-{foreground|fg} {color}]\n"
 "[-{background|bg} {color}] [-frame {color}]\n"
@@ -47,7 +47,13 @@ static const char optionsHelp[] = {
 
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
-"A simple 3D viewer."
+"A simple 3D viewer (though may need some work).\n"
+"\n"
+"The roll part does not seem to be quite right and may not\n"
+"track well.  Of note is the mouse to 3D surface detection.\n"
+"\n"
+"In the sample data, Cubes and F16 are big, so the polyhedrons\n"
+"are scaled up to them in the data file."
 };
 
 static const char featuresHelp[] = {
@@ -67,17 +73,11 @@ static const char featuresHelp[] = {
 "\n"
 "Press \"B\" or \"b\" keys to change object.\n"
 "\n"
-"Press \">\" or \".\" keys to speed up the movement "
-"(not implemented).\n"
-"\n"
-"Press \"<\" or \",\" keys to slow down the movement "
-"(not implemented).\n"
-"\n"
 "Press \"@\" key to toggle the sound.\n"
 "\n"
 "Press \"Esc\" key to hide program.\n"
 "\n"
-"Press \"Q\", \"fBq\", or \"CTRL-C\" keys kill program.\n"
+"Press \"Q\", \"q\", or \"CTRL-C\" keys kill program.\n"
 "\n"
 "Use the key pad or arrow keys to rotate object without the mouse.\n"
 "Key pad is defined for Threed as:\n"
@@ -86,16 +86,7 @@ static const char featuresHelp[] = {
 "  ^\n"
 "4<5>6   Left, Clockwise, Right\n"
 "  v\n"
-"  2     Down\n"
-"I debated releasing this, since it needs some work.  "
-"One neat thing is the mouse surface detection.  This\n"
-"viewer is real simple, it only primitive graphic "
-"routines, so it might be useful to someone out there.\n"
-"If you have any improvements to make, let me know.  "
-"I think the roll part is not quite right as it does\n"
-"not track well.\n"
-"In the sample data, Cubes and F16 are big, so the "
-"polyhedrons are scaled up to them in the data file."
+"  2     Down"
 };
 
 static const char referencesHelp[] = {
@@ -475,15 +466,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -629,6 +620,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #include <Xm/Scale.h>
 #include <Xm/ToggleB.h>
 #include <Xm/List.h>
+#include <Xm/Text.h>
 #include <Xm/Form.h>
 #define PRINT_MESSAGE(b) PrintState(message, b)
 #else
@@ -664,12 +656,13 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #define TITLE_LENGTH 2048
 
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 static Widget xDist, yDist, zDist, thetaAng, phiAng, psiAng;
 static Widget surfaceSwitch, objectList;
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
-static Arg arg[3];
+static Widget sysnopsisDialog, referencesDialog, aboutDialog;
 static char *progDsp;
+static Arg args[10];
 #else
 static char titleDsp[TITLE_LENGTH] = "";
 #endif
@@ -682,10 +675,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -986,8 +979,8 @@ createMenu(Widget *menu, Widget rowCol, int init)
 	icosa = XmStringCreateSimple("Icosahedron");
 	cubes = XmStringCreateSimple("Boxes");
 	f16 = XmStringCreateSimple("F16");
-	*menu = XmVaCreateSimpleOptionMenu(rowCol,
-		"mode_menu", choice, 'M', init, object_response,
+	*menu = XmVaCreateSimpleOptionMenu(rowCol, "modeMenu",
+		choice, 'M', init, object_response,
 		XmVaPUSHBUTTON, tetra, 'T', NULL, NULL,
 		XmVaPUSHBUTTON, hexa, 'H', NULL, NULL,
 		XmVaPUSHBUTTON, octa, 'O', NULL, NULL,
@@ -1062,11 +1055,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1077,6 +1070,58 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+#if 0
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+#endif
+
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
@@ -1108,7 +1153,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(sysnopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1163,7 +1208,7 @@ int main(int argc, char **argv)
 	XmStringFree(fileString);
 	XmStringFree(controlsString);
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
@@ -1195,9 +1240,9 @@ int main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1208,16 +1253,6 @@ int main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	mainPanel = XtCreateManagedWidget("mainPanel",
 		xmPanedWindowWidgetClass, panel,
 		NULL, 0);
@@ -1343,6 +1378,16 @@ int main(int argc, char **argv)
 	XtAddCallback(threed, XtNselectCallback,
 		(XtCallbackProc) callbackThreeD, (XtPointer) NULL);
 #ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	sysnopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
 	shapeRowCol = XtVaCreateManagedWidget("shapeRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNorientation, XmHORIZONTAL,
