@@ -83,7 +83,7 @@ static void clearWithQueryPuzzle(TrianglesWidget w,
 	XEvent *event, char **args, int nArgs);
 static void clearWithDoubleClickPuzzle(TrianglesWidget w,
 	XEvent *event, char **args, int nArgs);
-static void getPuzzle(TrianglesWidget w,
+static void readPuzzle(TrianglesWidget w,
 	XEvent *event, char **args, int nArgs);
 static void writePuzzle(TrianglesWidget w,
 	XEvent *event, char **args, int nArgs);
@@ -163,10 +163,10 @@ static char translations[] =
  <Btn1Up>: Release()\n\
  <Btn3Down>: ClearMaybe()\n\
  <Btn3Down>(2+): Clear2()\n\
- <KeyPress>g: Get()\n\
+ <KeyPress>r: Read()\n\
  <KeyPress>w: Write()\n\
  <KeyPress>u: Undo()\n\
- <KeyPress>r: Redo()\n\
+ <KeyPress>e: Redo()\n\
  <KeyPress>c: Clear()\n\
  <KeyPress>z: Randomize()\n\
  <KeyPress>s: Solve()\n\
@@ -189,7 +189,7 @@ static XtActionsRec actionsList[] =
 	{(char *) "Release", (XtActionProc) releasePuzzle},
 	{(char *) "ClearMaybe", (XtActionProc) clearWithQueryPuzzle},
 	{(char *) "Clear2", (XtActionProc) clearWithDoubleClickPuzzle},
-	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Read", (XtActionProc) readPuzzle},
 	{(char *) "Write", (XtActionProc) writePuzzle},
 	{(char *) "Undo", (XtActionProc) undoPuzzle},
 	{(char *) "Redo", (XtActionProc) redoPuzzle},
@@ -1730,7 +1730,7 @@ randomizeTiles(TrianglesWidget w)
 }
 
 static void
-getTiles(TrianglesWidget w)
+readTiles(TrianglesWidget w)
 {
 	FILE *fp;
 	int c, i, size, moves;
@@ -1748,7 +1748,7 @@ getTiles(TrianglesWidget w)
 	if ((fp = fopen(name, "r")) == NULL) {
 		name = fname;
 		if ((fp = fopen(name, "r")) == NULL) {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, " or ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -1762,7 +1762,7 @@ getTiles(TrianglesWidget w)
 /* Probably annoying */
 #if 0
 		else {
-			stringCat(&buf1, "Can not read (get) ", lname);
+			stringCat(&buf1, "Can not read ", lname);
 			stringCat(&buf2, buf1, ", falling back to ");
 			free(buf1);
 			stringCat(&buf1, buf2, fname);
@@ -2250,8 +2250,8 @@ setValuesPuzzle(Widget current, Widget request, Widget renew)
 
 		w->triangles.menu = ACTION_IGNORE;
 		switch (menu) {
-		case ACTION_GET:
-			getTiles(w);
+		case ACTION_READ:
+			readTiles(w);
 			break;
 		case ACTION_WRITE:
 			writeTiles(w);
@@ -2703,13 +2703,13 @@ clearWithDoubleClickPuzzle(TrianglesWidget w
 static
 #endif
 void
-getPuzzle(TrianglesWidget w
+readPuzzle(TrianglesWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
 )
 {
-	getTiles(w);
+	readTiles(w);
 }
 
 #ifndef WINVER
