@@ -2,7 +2,7 @@
 /*
  * @(#)Triangles.h
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -75,7 +75,7 @@ typedef struct {
 } trianglesCallbackStruct;
 #endif
 
-#define ACTION_GET 100
+#define ACTION_READ 100
 #define ACTION_WRITE 101
 #define ACTION_EXIT 102
 #define ACTION_HIDE 103
