@@ -1,7 +1,7 @@
 /*
  * @(#)xtriangles.c
  *
- * Copyright 1993 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -30,7 +30,7 @@ static const char aboutHelp[] = {
 "http://www.tux.org/~bagleyd/puzzles.html"
 };
 
-static const char optionsHelp[] = {
+static const char synopsisHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
@@ -46,7 +46,7 @@ static const char optionsHelp[] = {
 static const char descriptionHelp[] = {
 "A sliding tile puzzle.  A triangular version of the "
 "15 puzzle which was originally made around 1879 (the 14-15\n"
-"puzzle of Sam Loyd was made soon after).   T. R. Dawson "
+"puzzle of Sam Loyd was made soon after).  T. R. Dawson "
 "in Original Puzzles has a similar puzzle with 4 diamond-\n"
 "and 6 triangular-shaped pieces.  This puzzle is easier to "
 "solve than 15 puzzle."
@@ -56,20 +56,20 @@ static const char featuresHelp[] = {
 "Click \"mouse-left\" button to move a tile.  Clicks on "
 "spaces, or clicks on tiles that are not in line with\n"
 "two spaces will not move tiles.  Notice, one can move "
-"more than  one tile at a time  by clicking on\n"
+"more than one tile at a time by clicking on\n"
 "the tile farthest from the spaces but still in line with the "
 "spaces.\n"
 "\n"
 "Click \"mouse-right\" button, or press \"C\" or \"c\" "
 "keys, to clear the puzzle.\n"
 "\n"
-"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+"Press \"R\" or \"r\" keys to read a saved puzzle.\n"
 "\n"
 "Press \"W\" or \"w\" keys to save (write) a puzzle.\n"
 "\n"
 "Press \"U\" or \"u\" keys to undo a move.\n"
 "\n"
-"Press \"R\" or \"r\" keys to redo a move.\n"
+"Press \"E\" or \"e\" keys to redo a move.\n"
 "\n"
 "Press \"Z\" or \"z\" keys to randomize the puzzle.  New records "
 "can only be set from a cleared state.\n"
@@ -101,11 +101,11 @@ static const char featuresHelp[] = {
 };
 
 static const char referencesHelp[] = {
-"L. E. Horden, Sliding Piece Puzzles  (Recreations in "
-"Mathematics Series), Oxford University Press  1986,\n"
+"L. E. Horden, Sliding Piece Puzzles (Recreations in "
+"Mathematics Series), Oxford University Press 1986,\n"
 "pp 1, 148, 149.\n"
 "Jerry Slocum & Jack Botermans, Puzzles Old & New (How to Make "
-"and Solve Them),  University of Washington\n"
+"and Solve Them), University of Washington\n"
 "Press, Seattle 1987, p 126, 127."
 };
 #endif
@@ -143,6 +143,8 @@ static TrianglesRec widget;
 #include <Xm/PushBG.h>
 #include <Xm/CascadeB.h>
 #include <Xm/Scale.h>
+#include <Xm/Text.h>
+#include <Xm/Form.h>
 #ifdef MOUSEBITMAPS
 #include "pixmaps/mouse-l.xbm"
 #include "pixmaps/mouse-r.xbm"
@@ -210,6 +212,7 @@ static char messageDsp[MESSAGE_LENGTH] = "Welcome";
 static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
+#define SCROLL_SIZE 30		/* A page */
 #define MIN_SPEED 1
 #define MAX_SPEED 50
 #ifdef ANIMATE
@@ -218,9 +221,9 @@ static Widget speedSlider;
 static Widget movesText, recordText, message, tileSlider;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
-static Widget optionsDialog, referencesDialog, aboutDialog;
+static Widget synopsisDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, clearDialog;
-static Arg arg[3];
+static Arg args[10];
 #else
 static char titleDsp[TITLE_LENGTH] = "";
 #endif
@@ -394,7 +397,8 @@ printRecord(int size)
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
 		(void) sprintf(recordDsp, "%d %s",
-			puzzleRecord[i].score, puzzleRecord[i].name);
+			puzzleRecord[i].score,
+			puzzleRecord[i].name);
 	}
 #ifdef HAVE_MOTIF
 	printState(recordText, recordDsp);
@@ -586,7 +590,7 @@ puzzleListener(Widget w, caddr_t clientData,
 		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
-			break;
+		break;
 	case ACTION_RESTORE:
 	case ACTION_RESET:
 		movesDsp = 0;
@@ -773,8 +777,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		break;
 	case WM_COMMAND:
 		switch (LOWORD(wParam)) {
-		case ACTION_GET:
-			getPuzzle(&widget);
+		case ACTION_READ:
+			readPuzzle(&widget);
 			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -856,15 +860,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_DESCRIPTION:
 			(void) MessageBox(hWnd, descriptionHelp,
-				"Description", MB_OK);
+				"Description", MB_OK | MB_ICONQUESTION);
 			break;
 		case ACTION_FEATURES:
 			(void) MessageBox(hWnd, featuresHelp,
-				"Features", MB_OK);
+				"Features", MB_OK | MB_ICONEXCLAMATION);
 			break;
 		case ACTION_REFERENCES:
 			(void) MessageBox(hWnd, referencesHelp,
-				"References", MB_OK);
+				"References", MB_OK | MB_ICONINFORMATION);
 			break;
 		case ACTION_ABOUT:
 			(void) DialogBox(widget.core.hInstance,
@@ -934,10 +938,10 @@ usage(char *programName)
 	unsigned int i;
 
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	for (i = 0; i < strlen(optionsHelp); i++) {
-		if (i == 0 || optionsHelp[i - 1] == '\n')
+	for (i = 0; i < strlen(synopsisHelp); i++) {
+		if (i == 0 || synopsisHelp[i - 1] == '\n')
 			(void) fprintf(stderr, "\t");
-		(void) fprintf(stderr, "%c", (optionsHelp[i]));
+		(void) fprintf(stderr, "%c", (synopsisHelp[i]));
 	}
 	(void) fprintf(stderr, "\n");
 	exit(1);
@@ -1020,7 +1024,7 @@ speedChangeListener(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 fileMenuListener(Widget w, void *value, void *clientData)
 {
-	int val = (int) value + ACTION_GET;
+	int val = (int) value + ACTION_READ;
 
 	if (val == ACTION_EXIT)
 		exit(0);
@@ -1028,10 +1032,12 @@ fileMenuListener(Widget w, void *value, void *clientData)
 }
 
 static void
-playCB(Widget w, void *value, void *clientData)
+playMenuListener(Widget w, void *value, void *clientData)
 {
 	int val = (int) value + ACTION_UNDO;
 
+	if (val >= ACTION_INCREMENT)
+		val += ACTION_SOUND - ACTION_INCREMENT;
 	XtVaSetValues(puzzle, XtNmenu, val, NULL);
 }
 
@@ -1047,10 +1053,10 @@ createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 	messageString = XmStringCreateLtoR(text, charSet);
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNmessageString, messageString);
 	messageBox = XmCreateWarningDialog(w, (char *) "queryBox",
-		arg, 2);
+		args, 2);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
 	XtUnmanageChild(button);
 	XmStringFree(titleString);
@@ -1074,11 +1080,11 @@ createHelp(Widget w, char *text, char *title)
 	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
 	titleString = XmStringCreateSimple((char *) titleDsp);
 	buttonString = XmStringCreateSimple((char *) "OK");
-	XtSetArg(arg[0], XmNdialogTitle, titleString);
-	XtSetArg(arg[1], XmNokLabelString, buttonString);
-	XtSetArg(arg[2], XmNmessageString, messageString);
+	XtSetArg(args[0], XmNdialogTitle, titleString);
+	XtSetArg(args[1], XmNokLabelString, buttonString);
+	XtSetArg(args[2], XmNmessageString, messageString);
 	messageBox = XmCreateInformationDialog(w, (char *) "helpBox",
-		arg, 3);
+		args, 3);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_CANCEL_BUTTON);
 	XtUnmanageChild(button);
 	button = XmMessageBoxGetChild(messageBox, XmDIALOG_HELP_BUTTON);
@@ -1089,6 +1095,57 @@ createHelp(Widget w, char *text, char *title)
 	return messageBox;
 }
 
+/*http://www.ist.co.uk/motif/books/vol6A/ch-5.fm.html*/
+static Widget
+createScrollHelp(Widget w, char *text, char *title)
+{
+	Widget dialog, pane, scrolledText, form, label, button;
+	int n = 0;
+	char titleDsp[FILE_NAME_LENGTH + 8];
+	XmString titleString = NULL;
+
+	(void) sprintf(titleDsp, "%s: %s", progDsp, title);
+	dialog = XmCreateMessageDialog(w, titleDsp, NULL, 0);
+	titleString = XmStringCreateSimple((char *) titleDsp);
+	pane = XtVaCreateWidget("pane", xmPanedWindowWidgetClass, dialog,
+		XmNsashWidth, 1, XmNsashHeight, 1, NULL);
+	form = XtVaCreateWidget("form", xmFormWidgetClass, pane, NULL);
+	label = XtVaCreateManagedWidget("label", xmLabelGadgetClass, form,
+		XmNlabelType, XmPIXMAP,
+		XmNlabelPixmap, pixmap,
+		XmNleftAttachment, XmATTACH_FORM,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XtSetArg(args[n], XmNdialogTitle, titleString); n++;
+	XtSetArg(args[n], XmNscrollVertical, True); n++;
+	XtSetArg(args[n], XmNscrollHorizontal, False); n++;
+	XtSetArg(args[n], XmNeditMode, XmMULTI_LINE_EDIT); n++;
+	XtSetArg(args[n], XmNeditable, False); n++;
+	XtSetArg(args[n], XmNcursorPositionVisible, False); n++;
+	XtSetArg(args[n], XmNwordWrap, False); n++;
+	XtSetArg(args[n], XmNresizeWidth, True); n++;
+	XtSetArg(args[n], XmNvalue, text); n++;
+	XtSetArg(args[n], XmNrows, SCROLL_SIZE); n++;
+	scrolledText = XmCreateScrolledText(form, "helpText", args, n);
+	XtVaSetValues(XtParent(scrolledText),
+		XmNleftAttachment, XmATTACH_WIDGET,
+		XmNleftWidget, label,
+		XmNtopAttachment, XmATTACH_FORM,
+		XmNrightAttachment, XmATTACH_FORM,
+		XmNbottomAttachment, XmATTACH_FORM,
+		NULL);
+	XmStringFree(titleString);
+	XtManageChild(scrolledText);
+	XtManageChild(form);
+	XtManageChild(pane);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON);
+	XtUnmanageChild(button);
+	button = XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON);
+	XtUnmanageChild(button);
+	return dialog;
+}
+
 static void
 helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 {
@@ -1102,7 +1159,7 @@ helpMenuListener(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(optionsDialog);
+		XtManageChild(synopsisDialog);
 		break;
 	case 3:
 		XtManageChild(referencesDialog);
@@ -1129,13 +1186,16 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 	Widget menuBar, pullDownMenu, widget;
 	Widget menuBarPanel, mainPanel, controlPanel;
-	Widget movesRowCol, tilesRowCol, messageRowCol;
+	Widget movesRowCol, sliderRowCol, messageRowCol;
 	XmString fileString, playString;
-	XmString getString, writeString, quitString;
+	XmString readString, writeString, quitString;
 	XmString undoString, redoString;
 	XmString clearString, randomizeString, solveString;
+#ifdef EXTRA
 	XmString incrementString, decrementString;
-	XmString speedString, slowString, soundString;
+	XmString speedString, slowString;
+#endif
+	XmString soundString;
 #endif
 
 	progDsp = argv[0];
@@ -1158,17 +1218,17 @@ main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(playString);
-	getString = XmStringCreateSimple((char *) "Get");
+	readString = XmStringCreateSimple((char *) "Read");
 	writeString = XmStringCreateSimple((char *) "Write");
 	quitString = XmStringCreateSimple((char *) "Exit");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "fileMenu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
+		XmVaPUSHBUTTON, readString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
 		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
-	XmStringFree(getString);
+	XmStringFree(readString);
 	XmStringFree(writeString);
 	XmStringFree(quitString);
 	undoString = XmStringCreateSimple((char *) "Undo");
@@ -1176,22 +1236,26 @@ main(int argc, char **argv)
 	clearString = XmStringCreateSimple((char *) "Clear");
 	randomizeString = XmStringCreateSimple((char *) "Randomize");
 	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
+#ifdef EXTRA
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	speedString = XmStringCreateSimple((char *) "Speed >");
 	slowString = XmStringCreateSimple((char *) "Slow <");
+#endif
 	soundString = XmStringCreateSimple((char *) "Sound @");
-	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
-		1, playCB,
+	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "playMenu",
+		1, playMenuListener,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
-		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
+		XmVaPUSHBUTTON, redoString, 'e', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
 		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
+#ifdef EXTRA
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+#endif
 		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		NULL);
 	XmStringFree(undoString);
@@ -1199,10 +1263,12 @@ main(int argc, char **argv)
 	XmStringFree(clearString);
 	XmStringFree(randomizeString);
 	XmStringFree(solveString);
+#ifdef EXTRA
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
 	XmStringFree(speedString);
 	XmStringFree(slowString);
+#endif
 	XmStringFree(soundString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
@@ -1219,9 +1285,9 @@ main(int argc, char **argv)
 		xmPushButtonGadgetClass, pullDownMenu,
 		XmNmnemonic, 'F', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 1);
-	widget = XtVaCreateManagedWidget("Options",
+	widget = XtVaCreateManagedWidget("Synopsis",
 		xmPushButtonGadgetClass, pullDownMenu,
-		XmNmnemonic, 'O', NULL);
+		XmNmnemonic, 'S', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 2);
 	widget = XtVaCreateManagedWidget("References",
 		xmPushButtonGadgetClass, pullDownMenu,
@@ -1232,16 +1298,6 @@ main(int argc, char **argv)
 		XmNmnemonic, 'A', NULL);
 	XtAddCallback(widget, XmNactivateCallback, helpMenuListener, (char *) 4);
 	XtManageChild(menuBar);
-	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
-		(char *) "Description");
-	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
-		(char *) "Features");
-	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
-		(char *) "Options");
-	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
-		(char *) "References");
-	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
-		(char *) "About");
 	solveDialog = createHelp(menuBar, (char *) solveHelp,
 		(char *) "Solve");
 	clearDialog = createQuery(topLevel,
@@ -1258,7 +1314,7 @@ main(int argc, char **argv)
 		XmNsashHeight, 1, NULL);
 	movesRowCol = XtVaCreateManagedWidget("movesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
-		XmNnumColumns, 2,
+		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 #ifdef MOUSEBITMAPS
@@ -1310,13 +1366,13 @@ main(int argc, char **argv)
 		XtVaTypedArg, XmNlabelString, XmRString, "Record", 7, NULL);
 	recordText = XtVaCreateManagedWidget("0",
 		xmLabelWidgetClass, movesRowCol, NULL);
-	tilesRowCol = XtVaCreateManagedWidget("tilesRowCol",
+	sliderRowCol = XtVaCreateManagedWidget("tilesRowCol",
 		xmRowColumnWidgetClass, controlPanel,
 		XmNnumColumns, 1,
 		XmNorientation, XmHORIZONTAL,
 		XmNpacking, XmPACK_COLUMN, NULL);
 	tileSlider = XtVaCreateManagedWidget("tile",
-		xmScaleWidgetClass, tilesRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
 		XmNminimum, MIN_TILES,
 		XmNmaximum, MAX_TILES,
@@ -1327,7 +1383,7 @@ main(int argc, char **argv)
 		(XtCallbackProc) tileChangeListener, (XtPointer) NULL);
 #ifdef ANIMATE
 	speedSlider = XtVaCreateManagedWidget("speedSlider",
-		xmScaleWidgetClass, tilesRowCol,
+		xmScaleWidgetClass, sliderRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
 		XmNminimum, MIN_SPEED,
 		XmNmaximum, MAX_SPEED,
@@ -1381,6 +1437,18 @@ main(int argc, char **argv)
 		XtNiconPixmap, pixmap, NULL);
 	XtAddCallback(puzzle, XtNselectCallback,
 		(XtCallbackProc) puzzleListener, (XtPointer) NULL);
+#ifdef HAVE_MOTIF
+	descriptionDialog = createHelp(menuBar, (char *) descriptionHelp,
+		(char *) "Description");
+	featuresDialog = createScrollHelp(menuBar, (char *) featuresHelp,
+		(char *) "Features");
+	synopsisDialog = createHelp(menuBar, (char *) synopsisHelp,
+		(char *) "Synopsis");
+	referencesDialog = createHelp(menuBar, (char *) referencesHelp,
+		(char *) "References");
+	aboutDialog = createHelp(menuBar, (char *) aboutHelp,
+		(char *) "About");
+#endif
 	initialize(puzzle);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(puzzle), (unsigned int) AnyButton, AnyModifier,
